"""File generated by TLObjects' generator. All changes will be ERASED"""

import telethon.tl.types.res_pq
import telethon.tl.types.p_q_inner_data
import telethon.tl.types.server_dh_params_fail
import telethon.tl.types.server_dh_params_ok
import telethon.tl.types.server_dh_inner_data
import telethon.tl.types.client_dh_inner_data
import telethon.tl.types.dh_gen_ok
import telethon.tl.types.dh_gen_retry
import telethon.tl.types.dh_gen_fail
import telethon.tl.functions.req_pq
import telethon.tl.functions.req_dh_params
import telethon.tl.functions.set_client_dh_params
import telethon.tl.types.msgs_ack
import telethon.tl.types.bad_msg_notification
import telethon.tl.types.bad_server_salt
import telethon.tl.types.msgs_state_req
import telethon.tl.types.msgs_state_info
import telethon.tl.types.msgs_all_info
import telethon.tl.types.msg_detailed_info
import telethon.tl.types.msg_new_detailed_info
import telethon.tl.types.msg_resend_req
import telethon.tl.types.rpc_error
import telethon.tl.types.rpc_answer_unknown
import telethon.tl.types.rpc_answer_dropped_running
import telethon.tl.types.rpc_answer_dropped
import telethon.tl.types.future_salt
import telethon.tl.types.future_salts
import telethon.tl.types.pong
import telethon.tl.types.destroy_session_ok
import telethon.tl.types.destroy_session_none
import telethon.tl.types.new_session_created
import telethon.tl.types.http_wait
import telethon.tl.functions.rpc_drop_answer
import telethon.tl.functions.get_future_salts
import telethon.tl.functions.ping
import telethon.tl.functions.ping_delay_disconnect
import telethon.tl.functions.destroy_session
import telethon.tl.functions.contest.save_developer_info
import telethon.tl.types.error
import telethon.tl.types.null
import telethon.tl.types.input_peer_empty
import telethon.tl.types.input_peer_self
import telethon.tl.types.input_peer_chat
import telethon.tl.types.input_peer_user
import telethon.tl.types.input_peer_channel
import telethon.tl.types.input_user_empty
import telethon.tl.types.input_user_self
import telethon.tl.types.input_user
import telethon.tl.types.input_phone_contact
import telethon.tl.types.input_file
import telethon.tl.types.input_file_big
import telethon.tl.types.input_media_empty
import telethon.tl.types.input_media_uploaded_photo
import telethon.tl.types.input_media_photo
import telethon.tl.types.input_media_geo_point
import telethon.tl.types.input_media_contact
import telethon.tl.types.input_media_uploaded_document
import telethon.tl.types.input_media_uploaded_thumb_document
import telethon.tl.types.input_media_document
import telethon.tl.types.input_media_venue
import telethon.tl.types.input_media_gif_external
import telethon.tl.types.input_media_photo_external
import telethon.tl.types.input_media_document_external
import telethon.tl.types.input_media_game
import telethon.tl.types.input_chat_photo_empty
import telethon.tl.types.input_chat_uploaded_photo
import telethon.tl.types.input_chat_photo
import telethon.tl.types.input_geo_point_empty
import telethon.tl.types.input_geo_point
import telethon.tl.types.input_photo_empty
import telethon.tl.types.input_photo
import telethon.tl.types.input_file_location
import telethon.tl.types.input_encrypted_file_location
import telethon.tl.types.input_document_file_location
import telethon.tl.types.input_app_event
import telethon.tl.types.peer_user
import telethon.tl.types.peer_chat
import telethon.tl.types.peer_channel
import telethon.tl.types.storage.file_unknown
import telethon.tl.types.storage.file_jpeg
import telethon.tl.types.storage.file_gif
import telethon.tl.types.storage.file_png
import telethon.tl.types.storage.file_pdf
import telethon.tl.types.storage.file_mp3
import telethon.tl.types.storage.file_mov
import telethon.tl.types.storage.file_partial
import telethon.tl.types.storage.file_mp4
import telethon.tl.types.storage.file_webp
import telethon.tl.types.file_location_unavailable
import telethon.tl.types.file_location
import telethon.tl.types.user_empty
import telethon.tl.types.user
import telethon.tl.types.user_profile_photo_empty
import telethon.tl.types.user_profile_photo
import telethon.tl.types.user_status_empty
import telethon.tl.types.user_status_online
import telethon.tl.types.user_status_offline
import telethon.tl.types.user_status_recently
import telethon.tl.types.user_status_last_week
import telethon.tl.types.user_status_last_month
import telethon.tl.types.chat_empty
import telethon.tl.types.chat
import telethon.tl.types.chat_forbidden
import telethon.tl.types.channel
import telethon.tl.types.channel_forbidden
import telethon.tl.types.chat_full
import telethon.tl.types.channel_full
import telethon.tl.types.chat_participant
import telethon.tl.types.chat_participant_creator
import telethon.tl.types.chat_participant_admin
import telethon.tl.types.chat_participants_forbidden
import telethon.tl.types.chat_participants
import telethon.tl.types.chat_photo_empty
import telethon.tl.types.chat_photo
import telethon.tl.types.message_empty
import telethon.tl.types.message
import telethon.tl.types.message_service
import telethon.tl.types.message_media_empty
import telethon.tl.types.message_media_photo
import telethon.tl.types.message_media_geo
import telethon.tl.types.message_media_contact
import telethon.tl.types.message_media_unsupported
import telethon.tl.types.message_media_document
import telethon.tl.types.message_media_web_page
import telethon.tl.types.message_media_venue
import telethon.tl.types.message_media_game
import telethon.tl.types.message_action_empty
import telethon.tl.types.message_action_chat_create
import telethon.tl.types.message_action_chat_edit_title
import telethon.tl.types.message_action_chat_edit_photo
import telethon.tl.types.message_action_chat_delete_photo
import telethon.tl.types.message_action_chat_add_user
import telethon.tl.types.message_action_chat_delete_user
import telethon.tl.types.message_action_chat_joined_by_link
import telethon.tl.types.message_action_channel_create
import telethon.tl.types.message_action_chat_migrate_to
import telethon.tl.types.message_action_channel_migrate_from
import telethon.tl.types.message_action_pin_message
import telethon.tl.types.message_action_history_clear
import telethon.tl.types.message_action_game_score
import telethon.tl.types.dialog
import telethon.tl.types.photo_empty
import telethon.tl.types.photo
import telethon.tl.types.photo_size_empty
import telethon.tl.types.photo_size
import telethon.tl.types.photo_cached_size
import telethon.tl.types.geo_point_empty
import telethon.tl.types.geo_point
import telethon.tl.types.auth.checked_phone
import telethon.tl.types.auth.sent_code
import telethon.tl.types.auth.authorization
import telethon.tl.types.auth.exported_authorization
import telethon.tl.types.input_notify_peer
import telethon.tl.types.input_notify_users
import telethon.tl.types.input_notify_chats
import telethon.tl.types.input_notify_all
import telethon.tl.types.input_peer_notify_events_empty
import telethon.tl.types.input_peer_notify_events_all
import telethon.tl.types.input_peer_notify_settings
import telethon.tl.types.peer_notify_events_empty
import telethon.tl.types.peer_notify_events_all
import telethon.tl.types.peer_notify_settings_empty
import telethon.tl.types.peer_notify_settings
import telethon.tl.types.peer_settings
import telethon.tl.types.wall_paper
import telethon.tl.types.wall_paper_solid
import telethon.tl.types.input_report_reason_spam
import telethon.tl.types.input_report_reason_violence
import telethon.tl.types.input_report_reason_pornography
import telethon.tl.types.input_report_reason_other
import telethon.tl.types.user_full
import telethon.tl.types.contact
import telethon.tl.types.imported_contact
import telethon.tl.types.contact_blocked
import telethon.tl.types.contact_status
import telethon.tl.types.contacts.link
import telethon.tl.types.contacts.contacts_not_modified
import telethon.tl.types.contacts.contacts
import telethon.tl.types.contacts.imported_contacts
import telethon.tl.types.contacts.blocked
import telethon.tl.types.contacts.blocked_slice
import telethon.tl.types.messages.dialogs
import telethon.tl.types.messages.dialogs_slice
import telethon.tl.types.messages.messages
import telethon.tl.types.messages.messages_slice
import telethon.tl.types.messages.channel_messages
import telethon.tl.types.messages.chats
import telethon.tl.types.messages.chat_full
import telethon.tl.types.messages.affected_history
import telethon.tl.types.input_messages_filter_empty
import telethon.tl.types.input_messages_filter_photos
import telethon.tl.types.input_messages_filter_video
import telethon.tl.types.input_messages_filter_photo_video
import telethon.tl.types.input_messages_filter_photo_video_documents
import telethon.tl.types.input_messages_filter_document
import telethon.tl.types.input_messages_filter_url
import telethon.tl.types.input_messages_filter_gif
import telethon.tl.types.input_messages_filter_voice
import telethon.tl.types.input_messages_filter_music
import telethon.tl.types.input_messages_filter_chat_photos
import telethon.tl.types.update_new_message
import telethon.tl.types.update_message_id
import telethon.tl.types.update_delete_messages
import telethon.tl.types.update_user_typing
import telethon.tl.types.update_chat_user_typing
import telethon.tl.types.update_chat_participants
import telethon.tl.types.update_user_status
import telethon.tl.types.update_user_name
import telethon.tl.types.update_user_photo
import telethon.tl.types.update_contact_registered
import telethon.tl.types.update_contact_link
import telethon.tl.types.update_new_authorization
import telethon.tl.types.update_new_encrypted_message
import telethon.tl.types.update_encrypted_chat_typing
import telethon.tl.types.update_encryption
import telethon.tl.types.update_encrypted_messages_read
import telethon.tl.types.update_chat_participant_add
import telethon.tl.types.update_chat_participant_delete
import telethon.tl.types.update_dc_options
import telethon.tl.types.update_user_blocked
import telethon.tl.types.update_notify_settings
import telethon.tl.types.update_service_notification
import telethon.tl.types.update_privacy
import telethon.tl.types.update_user_phone
import telethon.tl.types.update_read_history_inbox
import telethon.tl.types.update_read_history_outbox
import telethon.tl.types.update_web_page
import telethon.tl.types.update_read_messages_contents
import telethon.tl.types.update_channel_too_long
import telethon.tl.types.update_channel
import telethon.tl.types.update_new_channel_message
import telethon.tl.types.update_read_channel_inbox
import telethon.tl.types.update_delete_channel_messages
import telethon.tl.types.update_channel_message_views
import telethon.tl.types.update_chat_admins
import telethon.tl.types.update_chat_participant_admin
import telethon.tl.types.update_new_sticker_set
import telethon.tl.types.update_sticker_sets_order
import telethon.tl.types.update_sticker_sets
import telethon.tl.types.update_saved_gifs
import telethon.tl.types.update_bot_inline_query
import telethon.tl.types.update_bot_inline_send
import telethon.tl.types.update_edit_channel_message
import telethon.tl.types.update_channel_pinned_message
import telethon.tl.types.update_bot_callback_query
import telethon.tl.types.update_edit_message
import telethon.tl.types.update_inline_bot_callback_query
import telethon.tl.types.update_read_channel_outbox
import telethon.tl.types.update_draft_message
import telethon.tl.types.update_read_featured_stickers
import telethon.tl.types.update_recent_stickers
import telethon.tl.types.update_config
import telethon.tl.types.update_pts_changed
import telethon.tl.types.updates.state
import telethon.tl.types.updates.difference_empty
import telethon.tl.types.updates.difference
import telethon.tl.types.updates.difference_slice
import telethon.tl.types.updates_too_long
import telethon.tl.types.update_short_message
import telethon.tl.types.update_short_chat_message
import telethon.tl.types.update_short
import telethon.tl.types.updates_combined
import telethon.tl.types.updates_tg
import telethon.tl.types.update_short_sent_message
import telethon.tl.types.photos.photos
import telethon.tl.types.photos.photos_slice
import telethon.tl.types.photos.photo
import telethon.tl.types.upload.file
import telethon.tl.types.dc_option
import telethon.tl.types.config
import telethon.tl.types.nearest_dc
import telethon.tl.types.help.app_update
import telethon.tl.types.help.no_app_update
import telethon.tl.types.help.invite_text
import telethon.tl.types.encrypted_chat_empty
import telethon.tl.types.encrypted_chat_waiting
import telethon.tl.types.encrypted_chat_requested
import telethon.tl.types.encrypted_chat
import telethon.tl.types.encrypted_chat_discarded
import telethon.tl.types.input_encrypted_chat
import telethon.tl.types.encrypted_file_empty
import telethon.tl.types.encrypted_file
import telethon.tl.types.input_encrypted_file_empty
import telethon.tl.types.input_encrypted_file_uploaded
import telethon.tl.types.input_encrypted_file
import telethon.tl.types.input_encrypted_file_big_uploaded
import telethon.tl.types.encrypted_message
import telethon.tl.types.encrypted_message_service
import telethon.tl.types.messages.dh_config_not_modified
import telethon.tl.types.messages.dh_config
import telethon.tl.types.messages.sent_encrypted_message
import telethon.tl.types.messages.sent_encrypted_file
import telethon.tl.types.input_document_empty
import telethon.tl.types.input_document
import telethon.tl.types.document_empty
import telethon.tl.types.document
import telethon.tl.types.help.support
import telethon.tl.types.notify_peer
import telethon.tl.types.notify_users
import telethon.tl.types.notify_chats
import telethon.tl.types.notify_all
import telethon.tl.types.send_message_typing_action
import telethon.tl.types.send_message_cancel_action
import telethon.tl.types.send_message_record_video_action
import telethon.tl.types.send_message_upload_video_action
import telethon.tl.types.send_message_record_audio_action
import telethon.tl.types.send_message_upload_audio_action
import telethon.tl.types.send_message_upload_photo_action
import telethon.tl.types.send_message_upload_document_action
import telethon.tl.types.send_message_geo_location_action
import telethon.tl.types.send_message_choose_contact_action
import telethon.tl.types.send_message_game_play_action
import telethon.tl.types.send_message_game_stop_action
import telethon.tl.types.contacts.found
import telethon.tl.types.input_privacy_key_status_timestamp
import telethon.tl.types.input_privacy_key_chat_invite
import telethon.tl.types.privacy_key_status_timestamp
import telethon.tl.types.privacy_key_chat_invite
import telethon.tl.types.input_privacy_value_allow_contacts
import telethon.tl.types.input_privacy_value_allow_all
import telethon.tl.types.input_privacy_value_allow_users
import telethon.tl.types.input_privacy_value_disallow_contacts
import telethon.tl.types.input_privacy_value_disallow_all
import telethon.tl.types.input_privacy_value_disallow_users
import telethon.tl.types.privacy_value_allow_contacts
import telethon.tl.types.privacy_value_allow_all
import telethon.tl.types.privacy_value_allow_users
import telethon.tl.types.privacy_value_disallow_contacts
import telethon.tl.types.privacy_value_disallow_all
import telethon.tl.types.privacy_value_disallow_users
import telethon.tl.types.account.privacy_rules
import telethon.tl.types.account_days_ttl
import telethon.tl.types.document_attribute_image_size
import telethon.tl.types.document_attribute_animated
import telethon.tl.types.document_attribute_sticker
import telethon.tl.types.document_attribute_video
import telethon.tl.types.document_attribute_audio
import telethon.tl.types.document_attribute_filename
import telethon.tl.types.document_attribute_has_stickers
import telethon.tl.types.messages.stickers_not_modified
import telethon.tl.types.messages.stickers
import telethon.tl.types.sticker_pack
import telethon.tl.types.messages.all_stickers_not_modified
import telethon.tl.types.messages.all_stickers
import telethon.tl.types.disabled_feature
import telethon.tl.types.messages.affected_messages
import telethon.tl.types.contact_link_unknown
import telethon.tl.types.contact_link_none
import telethon.tl.types.contact_link_has_phone
import telethon.tl.types.contact_link_contact
import telethon.tl.types.web_page_empty
import telethon.tl.types.web_page_pending
import telethon.tl.types.web_page
import telethon.tl.types.authorization
import telethon.tl.types.account.authorizations
import telethon.tl.types.account.no_password
import telethon.tl.types.account.password
import telethon.tl.types.account.password_settings
import telethon.tl.types.account.password_input_settings
import telethon.tl.types.auth.password_recovery
import telethon.tl.types.received_notify_message
import telethon.tl.types.chat_invite_empty
import telethon.tl.types.chat_invite_exported
import telethon.tl.types.chat_invite_already
import telethon.tl.types.chat_invite
import telethon.tl.types.input_sticker_set_empty
import telethon.tl.types.input_sticker_set_id
import telethon.tl.types.input_sticker_set_short_name
import telethon.tl.types.sticker_set
import telethon.tl.types.messages.sticker_set
import telethon.tl.types.bot_command
import telethon.tl.types.bot_info
import telethon.tl.types.keyboard_button
import telethon.tl.types.keyboard_button_url
import telethon.tl.types.keyboard_button_callback
import telethon.tl.types.keyboard_button_request_phone
import telethon.tl.types.keyboard_button_request_geo_location
import telethon.tl.types.keyboard_button_switch_inline
import telethon.tl.types.keyboard_button_game
import telethon.tl.types.keyboard_button_row
import telethon.tl.types.reply_keyboard_hide
import telethon.tl.types.reply_keyboard_force_reply
import telethon.tl.types.reply_keyboard_markup
import telethon.tl.types.reply_inline_markup
import telethon.tl.types.help.app_changelog_empty
import telethon.tl.types.help.app_changelog
import telethon.tl.types.message_entity_unknown
import telethon.tl.types.message_entity_mention
import telethon.tl.types.message_entity_hashtag
import telethon.tl.types.message_entity_bot_command
import telethon.tl.types.message_entity_url
import telethon.tl.types.message_entity_email
import telethon.tl.types.message_entity_bold
import telethon.tl.types.message_entity_italic
import telethon.tl.types.message_entity_code
import telethon.tl.types.message_entity_pre
import telethon.tl.types.message_entity_text_url
import telethon.tl.types.message_entity_mention_name
import telethon.tl.types.input_message_entity_mention_name
import telethon.tl.types.input_channel_empty
import telethon.tl.types.input_channel
import telethon.tl.types.contacts.resolved_peer
import telethon.tl.types.message_range
import telethon.tl.types.updates.channel_difference_empty
import telethon.tl.types.updates.channel_difference_too_long
import telethon.tl.types.updates.channel_difference
import telethon.tl.types.channel_messages_filter_empty
import telethon.tl.types.channel_messages_filter
import telethon.tl.types.channel_participant
import telethon.tl.types.channel_participant_self
import telethon.tl.types.channel_participant_moderator
import telethon.tl.types.channel_participant_editor
import telethon.tl.types.channel_participant_kicked
import telethon.tl.types.channel_participant_creator
import telethon.tl.types.channel_participants_recent
import telethon.tl.types.channel_participants_admins
import telethon.tl.types.channel_participants_kicked
import telethon.tl.types.channel_participants_bots
import telethon.tl.types.channel_role_empty
import telethon.tl.types.channel_role_moderator
import telethon.tl.types.channel_role_editor
import telethon.tl.types.channels.channel_participants
import telethon.tl.types.channels.channel_participant
import telethon.tl.types.help.terms_of_service
import telethon.tl.types.found_gif
import telethon.tl.types.found_gif_cached
import telethon.tl.types.messages.found_gifs
import telethon.tl.types.messages.saved_gifs_not_modified
import telethon.tl.types.messages.saved_gifs
import telethon.tl.types.input_bot_inline_message_media_auto
import telethon.tl.types.input_bot_inline_message_text
import telethon.tl.types.input_bot_inline_message_media_geo
import telethon.tl.types.input_bot_inline_message_media_venue
import telethon.tl.types.input_bot_inline_message_media_contact
import telethon.tl.types.input_bot_inline_message_game
import telethon.tl.types.input_bot_inline_result
import telethon.tl.types.input_bot_inline_result_photo
import telethon.tl.types.input_bot_inline_result_document
import telethon.tl.types.input_bot_inline_result_game
import telethon.tl.types.bot_inline_message_media_auto
import telethon.tl.types.bot_inline_message_text
import telethon.tl.types.bot_inline_message_media_geo
import telethon.tl.types.bot_inline_message_media_venue
import telethon.tl.types.bot_inline_message_media_contact
import telethon.tl.types.bot_inline_result
import telethon.tl.types.bot_inline_media_result
import telethon.tl.types.messages.bot_results
import telethon.tl.types.exported_message_link
import telethon.tl.types.message_fwd_header
import telethon.tl.types.auth.code_type_sms
import telethon.tl.types.auth.code_type_call
import telethon.tl.types.auth.code_type_flash_call
import telethon.tl.types.auth.sent_code_type_app
import telethon.tl.types.auth.sent_code_type_sms
import telethon.tl.types.auth.sent_code_type_call
import telethon.tl.types.auth.sent_code_type_flash_call
import telethon.tl.types.messages.bot_callback_answer
import telethon.tl.types.messages.message_edit_data
import telethon.tl.types.input_bot_inline_message_id
import telethon.tl.types.inline_bot_switch_pm
import telethon.tl.types.messages.peer_dialogs
import telethon.tl.types.top_peer
import telethon.tl.types.top_peer_category_bots_pm
import telethon.tl.types.top_peer_category_bots_inline
import telethon.tl.types.top_peer_category_correspondents
import telethon.tl.types.top_peer_category_groups
import telethon.tl.types.top_peer_category_channels
import telethon.tl.types.top_peer_category_peers
import telethon.tl.types.contacts.top_peers_not_modified
import telethon.tl.types.contacts.top_peers
import telethon.tl.types.draft_message_empty
import telethon.tl.types.draft_message
import telethon.tl.types.messages.featured_stickers_not_modified
import telethon.tl.types.messages.featured_stickers
import telethon.tl.types.messages.recent_stickers_not_modified
import telethon.tl.types.messages.recent_stickers
import telethon.tl.types.messages.archived_stickers
import telethon.tl.types.messages.sticker_set_install_result_success
import telethon.tl.types.messages.sticker_set_install_result_archive
import telethon.tl.types.sticker_set_covered
import telethon.tl.types.sticker_set_multi_covered
import telethon.tl.types.mask_coords
import telethon.tl.types.input_stickered_media_photo
import telethon.tl.types.input_stickered_media_document
import telethon.tl.types.game
import telethon.tl.types.input_game_id
import telethon.tl.types.input_game_short_name
import telethon.tl.types.high_score
import telethon.tl.types.messages.high_scores
import telethon.tl.functions.invoke_after_msg
import telethon.tl.functions.invoke_after_msgs
import telethon.tl.functions.init_connection
import telethon.tl.functions.invoke_with_layer
import telethon.tl.functions.invoke_without_updates
import telethon.tl.functions.auth.check_phone
import telethon.tl.functions.auth.send_code
import telethon.tl.functions.auth.sign_up
import telethon.tl.functions.auth.sign_in
import telethon.tl.functions.auth.log_out
import telethon.tl.functions.auth.reset_authorizations
import telethon.tl.functions.auth.send_invites
import telethon.tl.functions.auth.export_authorization
import telethon.tl.functions.auth.import_authorization
import telethon.tl.functions.auth.bind_temp_auth_key
import telethon.tl.functions.auth.import_bot_authorization
import telethon.tl.functions.auth.check_password
import telethon.tl.functions.auth.request_password_recovery
import telethon.tl.functions.auth.recover_password
import telethon.tl.functions.auth.resend_code
import telethon.tl.functions.auth.cancel_code
import telethon.tl.functions.auth.drop_temp_auth_keys
import telethon.tl.functions.account.register_device
import telethon.tl.functions.account.unregister_device
import telethon.tl.functions.account.update_notify_settings
import telethon.tl.functions.account.get_notify_settings
import telethon.tl.functions.account.reset_notify_settings
import telethon.tl.functions.account.update_profile
import telethon.tl.functions.account.update_status
import telethon.tl.functions.account.get_wall_papers
import telethon.tl.functions.account.report_peer
import telethon.tl.functions.account.check_username
import telethon.tl.functions.account.update_username
import telethon.tl.functions.account.get_privacy
import telethon.tl.functions.account.set_privacy
import telethon.tl.functions.account.delete_account
import telethon.tl.functions.account.get_account_ttl
import telethon.tl.functions.account.set_account_ttl
import telethon.tl.functions.account.send_change_phone_code
import telethon.tl.functions.account.change_phone
import telethon.tl.functions.account.update_device_locked
import telethon.tl.functions.account.get_authorizations
import telethon.tl.functions.account.reset_authorization
import telethon.tl.functions.account.get_password
import telethon.tl.functions.account.get_password_settings
import telethon.tl.functions.account.update_password_settings
import telethon.tl.functions.account.send_confirm_phone_code
import telethon.tl.functions.account.confirm_phone
import telethon.tl.functions.users.get_users
import telethon.tl.functions.users.get_full_user
import telethon.tl.functions.contacts.get_statuses
import telethon.tl.functions.contacts.get_contacts
import telethon.tl.functions.contacts.import_contacts
import telethon.tl.functions.contacts.delete_contact
import telethon.tl.functions.contacts.delete_contacts
import telethon.tl.functions.contacts.block
import telethon.tl.functions.contacts.unblock
import telethon.tl.functions.contacts.get_blocked
import telethon.tl.functions.contacts.export_card
import telethon.tl.functions.contacts.import_card
import telethon.tl.functions.contacts.search
import telethon.tl.functions.contacts.resolve_username
import telethon.tl.functions.contacts.get_top_peers
import telethon.tl.functions.contacts.reset_top_peer_rating
import telethon.tl.functions.messages.get_messages
import telethon.tl.functions.messages.get_dialogs
import telethon.tl.functions.messages.get_history
import telethon.tl.functions.messages.search
import telethon.tl.functions.messages.read_history
import telethon.tl.functions.messages.delete_history
import telethon.tl.functions.messages.delete_messages
import telethon.tl.functions.messages.received_messages
import telethon.tl.functions.messages.set_typing
import telethon.tl.functions.messages.send_message
import telethon.tl.functions.messages.send_media
import telethon.tl.functions.messages.forward_messages
import telethon.tl.functions.messages.report_spam
import telethon.tl.functions.messages.hide_report_spam
import telethon.tl.functions.messages.get_peer_settings
import telethon.tl.functions.messages.get_chats
import telethon.tl.functions.messages.get_full_chat
import telethon.tl.functions.messages.edit_chat_title
import telethon.tl.functions.messages.edit_chat_photo
import telethon.tl.functions.messages.add_chat_user
import telethon.tl.functions.messages.delete_chat_user
import telethon.tl.functions.messages.create_chat
import telethon.tl.functions.messages.forward_message
import telethon.tl.functions.messages.get_dh_config
import telethon.tl.functions.messages.request_encryption
import telethon.tl.functions.messages.accept_encryption
import telethon.tl.functions.messages.discard_encryption
import telethon.tl.functions.messages.set_encrypted_typing
import telethon.tl.functions.messages.read_encrypted_history
import telethon.tl.functions.messages.send_encrypted
import telethon.tl.functions.messages.send_encrypted_file
import telethon.tl.functions.messages.send_encrypted_service
import telethon.tl.functions.messages.received_queue
import telethon.tl.functions.messages.read_message_contents
import telethon.tl.functions.messages.get_all_stickers
import telethon.tl.functions.messages.get_web_page_preview
import telethon.tl.functions.messages.export_chat_invite
import telethon.tl.functions.messages.check_chat_invite
import telethon.tl.functions.messages.import_chat_invite
import telethon.tl.functions.messages.get_sticker_set
import telethon.tl.functions.messages.install_sticker_set
import telethon.tl.functions.messages.uninstall_sticker_set
import telethon.tl.functions.messages.start_bot
import telethon.tl.functions.messages.get_messages_views
import telethon.tl.functions.messages.toggle_chat_admins
import telethon.tl.functions.messages.edit_chat_admin
import telethon.tl.functions.messages.migrate_chat
import telethon.tl.functions.messages.search_global
import telethon.tl.functions.messages.reorder_sticker_sets
import telethon.tl.functions.messages.get_document_by_hash
import telethon.tl.functions.messages.search_gifs
import telethon.tl.functions.messages.get_saved_gifs
import telethon.tl.functions.messages.save_gif
import telethon.tl.functions.messages.get_inline_bot_results
import telethon.tl.functions.messages.set_inline_bot_results
import telethon.tl.functions.messages.send_inline_bot_result
import telethon.tl.functions.messages.get_message_edit_data
import telethon.tl.functions.messages.edit_message
import telethon.tl.functions.messages.edit_inline_bot_message
import telethon.tl.functions.messages.get_bot_callback_answer
import telethon.tl.functions.messages.set_bot_callback_answer
import telethon.tl.functions.messages.get_peer_dialogs
import telethon.tl.functions.messages.save_draft
import telethon.tl.functions.messages.get_all_drafts
import telethon.tl.functions.messages.get_featured_stickers
import telethon.tl.functions.messages.read_featured_stickers
import telethon.tl.functions.messages.get_recent_stickers
import telethon.tl.functions.messages.save_recent_sticker
import telethon.tl.functions.messages.clear_recent_stickers
import telethon.tl.functions.messages.get_archived_stickers
import telethon.tl.functions.messages.get_mask_stickers
import telethon.tl.functions.messages.get_attached_stickers
import telethon.tl.functions.messages.set_game_score
import telethon.tl.functions.messages.set_inline_game_score
import telethon.tl.functions.messages.get_game_high_scores
import telethon.tl.functions.messages.get_inline_game_high_scores
import telethon.tl.functions.updates.get_state
import telethon.tl.functions.updates.get_difference
import telethon.tl.functions.updates.get_channel_difference
import telethon.tl.functions.photos.update_profile_photo
import telethon.tl.functions.photos.upload_profile_photo
import telethon.tl.functions.photos.delete_photos
import telethon.tl.functions.photos.get_user_photos
import telethon.tl.functions.upload.save_file_part
import telethon.tl.functions.upload.get_file
import telethon.tl.functions.upload.save_big_file_part
import telethon.tl.functions.help.get_config
import telethon.tl.functions.help.get_nearest_dc
import telethon.tl.functions.help.get_app_update
import telethon.tl.functions.help.save_app_log
import telethon.tl.functions.help.get_invite_text
import telethon.tl.functions.help.get_support
import telethon.tl.functions.help.get_app_changelog
import telethon.tl.functions.help.get_terms_of_service
import telethon.tl.functions.channels.read_history
import telethon.tl.functions.channels.delete_messages
import telethon.tl.functions.channels.delete_user_history
import telethon.tl.functions.channels.report_spam
import telethon.tl.functions.channels.get_messages
import telethon.tl.functions.channels.get_participants
import telethon.tl.functions.channels.get_participant
import telethon.tl.functions.channels.get_channels
import telethon.tl.functions.channels.get_full_channel
import telethon.tl.functions.channels.create_channel
import telethon.tl.functions.channels.edit_about
import telethon.tl.functions.channels.edit_admin
import telethon.tl.functions.channels.edit_title
import telethon.tl.functions.channels.edit_photo
import telethon.tl.functions.channels.check_username
import telethon.tl.functions.channels.update_username
import telethon.tl.functions.channels.join_channel
import telethon.tl.functions.channels.leave_channel
import telethon.tl.functions.channels.invite_to_channel
import telethon.tl.functions.channels.kick_from_channel
import telethon.tl.functions.channels.export_invite
import telethon.tl.functions.channels.delete_channel
import telethon.tl.functions.channels.toggle_invites
import telethon.tl.functions.channels.export_message_link
import telethon.tl.functions.channels.toggle_signatures
import telethon.tl.functions.channels.update_pinned_message
import telethon.tl.functions.channels.get_admined_public_channels

layer = 57  # Current generated layer

tlobjects = {
    0x5162463: telethon.tl.types.res_pq.ResPQ,
    0x83c95aec: telethon.tl.types.p_q_inner_data.PQInnerData,
    0x79cb045d: telethon.tl.types.server_dh_params_fail.ServerDHParamsFail,
    0xd0e8075c: telethon.tl.types.server_dh_params_ok.ServerDHParamsOk,
    0xb5890dba: telethon.tl.types.server_dh_inner_data.ServerDHInnerData,
    0x6643b654: telethon.tl.types.client_dh_inner_data.ClientDHInnerData,
    0x3bcbf734: telethon.tl.types.dh_gen_ok.DhGenOk,
    0x46dc1fb9: telethon.tl.types.dh_gen_retry.DhGenRetry,
    0xa69dae02: telethon.tl.types.dh_gen_fail.DhGenFail,
    0x60469778: telethon.tl.functions.req_pq.ReqPqRequest,
    0xd712e4be: telethon.tl.functions.req_dh_params.ReqDHParamsRequest,
    0xf5045f1f: telethon.tl.functions.set_client_dh_params.SetClientDHParamsRequest,
    0x62d6b459: telethon.tl.types.msgs_ack.MsgsAck,
    0xa7eff811: telethon.tl.types.bad_msg_notification.BadMsgNotification,
    0xedab447b: telethon.tl.types.bad_server_salt.BadServerSalt,
    0xda69fb52: telethon.tl.types.msgs_state_req.MsgsStateReq,
    0x4deb57d: telethon.tl.types.msgs_state_info.MsgsStateInfo,
    0x8cc0d131: telethon.tl.types.msgs_all_info.MsgsAllInfo,
    0x276d3ec6: telethon.tl.types.msg_detailed_info.MsgDetailedInfo,
    0x809db6df: telethon.tl.types.msg_new_detailed_info.MsgNewDetailedInfo,
    0x7d861a08: telethon.tl.types.msg_resend_req.MsgResendReq,
    0x2144ca19: telethon.tl.types.rpc_error.RpcError,
    0x5e2ad36e: telethon.tl.types.rpc_answer_unknown.RpcAnswerUnknown,
    0xcd78e586: telethon.tl.types.rpc_answer_dropped_running.RpcAnswerDroppedRunning,
    0xa43ad8b7: telethon.tl.types.rpc_answer_dropped.RpcAnswerDropped,
    0x949d9dc: telethon.tl.types.future_salt.FutureSalt,
    0xae500895: telethon.tl.types.future_salts.FutureSalts,
    0x347773c5: telethon.tl.types.pong.Pong,
    0xe22045fc: telethon.tl.types.destroy_session_ok.DestroySessionOk,
    0x62d350c9: telethon.tl.types.destroy_session_none.DestroySessionNone,
    0x9ec20908: telethon.tl.types.new_session_created.NewSessionCreated,
    0x9299359f: telethon.tl.types.http_wait.HttpWait,
    0x58e4a740: telethon.tl.functions.rpc_drop_answer.RpcDropAnswerRequest,
    0xb921bd04: telethon.tl.functions.get_future_salts.GetFutureSaltsRequest,
    0x7abe77ec: telethon.tl.functions.ping.PingRequest,
    0xf3427b8c: telethon.tl.functions.ping_delay_disconnect.PingDelayDisconnectRequest,
    0xe7512126: telethon.tl.functions.destroy_session.DestroySessionRequest,
    0x9a5f6e95: telethon.tl.functions.contest.save_developer_info.SaveDeveloperInfoRequest,
    0xc4b9f9bb: telethon.tl.types.error.Error,
    0x56730bcc: telethon.tl.types.null.Null,
    0x7f3b18ea: telethon.tl.types.input_peer_empty.InputPeerEmpty,
    0x7da07ec9: telethon.tl.types.input_peer_self.InputPeerSelf,
    0x179be863: telethon.tl.types.input_peer_chat.InputPeerChat,
    0x7b8e7de6: telethon.tl.types.input_peer_user.InputPeerUser,
    0x20adaef8: telethon.tl.types.input_peer_channel.InputPeerChannel,
    0xb98886cf: telethon.tl.types.input_user_empty.InputUserEmpty,
    0xf7c1b13f: telethon.tl.types.input_user_self.InputUserSelf,
    0xd8292816: telethon.tl.types.input_user.InputUser,
    0xf392b7f4: telethon.tl.types.input_phone_contact.InputPhoneContact,
    0xf52ff27f: telethon.tl.types.input_file.InputFile,
    0xfa4f0bb5: telethon.tl.types.input_file_big.InputFileBig,
    0x9664f57f: telethon.tl.types.input_media_empty.InputMediaEmpty,
    0x630c9af1: telethon.tl.types.input_media_uploaded_photo.InputMediaUploadedPhoto,
    0xe9bfb4f3: telethon.tl.types.input_media_photo.InputMediaPhoto,
    0xf9c44144: telethon.tl.types.input_media_geo_point.InputMediaGeoPoint,
    0xa6e45987: telethon.tl.types.input_media_contact.InputMediaContact,
    0xd070f1e9: telethon.tl.types.input_media_uploaded_document.InputMediaUploadedDocument,
    0x50d88cae: telethon.tl.types.input_media_uploaded_thumb_document.InputMediaUploadedThumbDocument,
    0x1a77f29c: telethon.tl.types.input_media_document.InputMediaDocument,
    0x2827a81a: telethon.tl.types.input_media_venue.InputMediaVenue,
    0x4843b0fd: telethon.tl.types.input_media_gif_external.InputMediaGifExternal,
    0xb55f4f18: telethon.tl.types.input_media_photo_external.InputMediaPhotoExternal,
    0xe5e9607c: telethon.tl.types.input_media_document_external.InputMediaDocumentExternal,
    0xd33f43f3: telethon.tl.types.input_media_game.InputMediaGame,
    0x1ca48f57: telethon.tl.types.input_chat_photo_empty.InputChatPhotoEmpty,
    0x927c55b4: telethon.tl.types.input_chat_uploaded_photo.InputChatUploadedPhoto,
    0x8953ad37: telethon.tl.types.input_chat_photo.InputChatPhoto,
    0xe4c123d6: telethon.tl.types.input_geo_point_empty.InputGeoPointEmpty,
    0xf3b7acc9: telethon.tl.types.input_geo_point.InputGeoPoint,
    0x1cd7bf0d: telethon.tl.types.input_photo_empty.InputPhotoEmpty,
    0xfb95c6c4: telethon.tl.types.input_photo.InputPhoto,
    0x14637196: telethon.tl.types.input_file_location.InputFileLocation,
    0xf5235d55: telethon.tl.types.input_encrypted_file_location.InputEncryptedFileLocation,
    0x430f0724: telethon.tl.types.input_document_file_location.InputDocumentFileLocation,
    0x770656a8: telethon.tl.types.input_app_event.InputAppEvent,
    0x9db1bc6d: telethon.tl.types.peer_user.PeerUser,
    0xbad0e5bb: telethon.tl.types.peer_chat.PeerChat,
    0xbddde532: telethon.tl.types.peer_channel.PeerChannel,
    0xaa963b05: telethon.tl.types.storage.file_unknown.FileUnknown,
    0x7efe0e: telethon.tl.types.storage.file_jpeg.FileJpeg,
    0xcae1aadf: telethon.tl.types.storage.file_gif.FileGif,
    0xa4f63c0: telethon.tl.types.storage.file_png.FilePng,
    0xae1e508d: telethon.tl.types.storage.file_pdf.FilePdf,
    0x528a0677: telethon.tl.types.storage.file_mp3.FileMp3,
    0x4b09ebbc: telethon.tl.types.storage.file_mov.FileMov,
    0x40bc6f52: telethon.tl.types.storage.file_partial.FilePartial,
    0xb3cea0e4: telethon.tl.types.storage.file_mp4.FileMp4,
    0x1081464c: telethon.tl.types.storage.file_webp.FileWebp,
    0x7c596b46: telethon.tl.types.file_location_unavailable.FileLocationUnavailable,
    0x53d69076: telethon.tl.types.file_location.FileLocation,
    0x200250ba: telethon.tl.types.user_empty.UserEmpty,
    0xd10d979a: telethon.tl.types.user.User,
    0x4f11bae1: telethon.tl.types.user_profile_photo_empty.UserProfilePhotoEmpty,
    0xd559d8c8: telethon.tl.types.user_profile_photo.UserProfilePhoto,
    0x9d05049: telethon.tl.types.user_status_empty.UserStatusEmpty,
    0xedb93949: telethon.tl.types.user_status_online.UserStatusOnline,
    0x8c703f: telethon.tl.types.user_status_offline.UserStatusOffline,
    0xe26f42f1: telethon.tl.types.user_status_recently.UserStatusRecently,
    0x7bf09fc: telethon.tl.types.user_status_last_week.UserStatusLastWeek,
    0x77ebc742: telethon.tl.types.user_status_last_month.UserStatusLastMonth,
    0x9ba2d800: telethon.tl.types.chat_empty.ChatEmpty,
    0xd91cdd54: telethon.tl.types.chat.Chat,
    0x7328bdb: telethon.tl.types.chat_forbidden.ChatForbidden,
    0xa14dca52: telethon.tl.types.channel.Channel,
    0x8537784f: telethon.tl.types.channel_forbidden.ChannelForbidden,
    0x2e02a614: telethon.tl.types.chat_full.ChatFull,
    0xc3d5512f: telethon.tl.types.channel_full.ChannelFull,
    0xc8d7493e: telethon.tl.types.chat_participant.ChatParticipant,
    0xda13538a: telethon.tl.types.chat_participant_creator.ChatParticipantCreator,
    0xe2d6e436: telethon.tl.types.chat_participant_admin.ChatParticipantAdmin,
    0xfc900c2b: telethon.tl.types.chat_participants_forbidden.ChatParticipantsForbidden,
    0x3f460fed: telethon.tl.types.chat_participants.ChatParticipants,
    0x37c1011c: telethon.tl.types.chat_photo_empty.ChatPhotoEmpty,
    0x6153276a: telethon.tl.types.chat_photo.ChatPhoto,
    0x83e5de54: telethon.tl.types.message_empty.MessageEmpty,
    0xc09be45f: telethon.tl.types.message.Message,
    0x9e19a1f6: telethon.tl.types.message_service.MessageService,
    0x3ded6320: telethon.tl.types.message_media_empty.MessageMediaEmpty,
    0x3d8ce53d: telethon.tl.types.message_media_photo.MessageMediaPhoto,
    0x56e0d474: telethon.tl.types.message_media_geo.MessageMediaGeo,
    0x5e7d2f39: telethon.tl.types.message_media_contact.MessageMediaContact,
    0x9f84f49e: telethon.tl.types.message_media_unsupported.MessageMediaUnsupported,
    0xf3e02ea8: telethon.tl.types.message_media_document.MessageMediaDocument,
    0xa32dd600: telethon.tl.types.message_media_web_page.MessageMediaWebPage,
    0x7912b71f: telethon.tl.types.message_media_venue.MessageMediaVenue,
    0xfdb19008: telethon.tl.types.message_media_game.MessageMediaGame,
    0xb6aef7b0: telethon.tl.types.message_action_empty.MessageActionEmpty,
    0xa6638b9a: telethon.tl.types.message_action_chat_create.MessageActionChatCreate,
    0xb5a1ce5a: telethon.tl.types.message_action_chat_edit_title.MessageActionChatEditTitle,
    0x7fcb13a8: telethon.tl.types.message_action_chat_edit_photo.MessageActionChatEditPhoto,
    0x95e3fbef: telethon.tl.types.message_action_chat_delete_photo.MessageActionChatDeletePhoto,
    0x488a7337: telethon.tl.types.message_action_chat_add_user.MessageActionChatAddUser,
    0xb2ae9b0c: telethon.tl.types.message_action_chat_delete_user.MessageActionChatDeleteUser,
    0xf89cf5e8: telethon.tl.types.message_action_chat_joined_by_link.MessageActionChatJoinedByLink,
    0x95d2ac92: telethon.tl.types.message_action_channel_create.MessageActionChannelCreate,
    0x51bdb021: telethon.tl.types.message_action_chat_migrate_to.MessageActionChatMigrateTo,
    0xb055eaee: telethon.tl.types.message_action_channel_migrate_from.MessageActionChannelMigrateFrom,
    0x94bd38ed: telethon.tl.types.message_action_pin_message.MessageActionPinMessage,
    0x9fbab604: telethon.tl.types.message_action_history_clear.MessageActionHistoryClear,
    0x92a72876: telethon.tl.types.message_action_game_score.MessageActionGameScore,
    0x66ffba14: telethon.tl.types.dialog.Dialog,
    0x2331b22d: telethon.tl.types.photo_empty.PhotoEmpty,
    0x9288dd29: telethon.tl.types.photo.Photo,
    0xe17e23c: telethon.tl.types.photo_size_empty.PhotoSizeEmpty,
    0x77bfb61b: telethon.tl.types.photo_size.PhotoSize,
    0xe9a734fa: telethon.tl.types.photo_cached_size.PhotoCachedSize,
    0x1117dd5f: telethon.tl.types.geo_point_empty.GeoPointEmpty,
    0x2049d70c: telethon.tl.types.geo_point.GeoPoint,
    0x811ea28e: telethon.tl.types.auth.checked_phone.CheckedPhone,
    0x5e002502: telethon.tl.types.auth.sent_code.SentCode,
    0xcd050916: telethon.tl.types.auth.authorization.Authorization,
    0xdf969c2d: telethon.tl.types.auth.exported_authorization.ExportedAuthorization,
    0xb8bc5b0c: telethon.tl.types.input_notify_peer.InputNotifyPeer,
    0x193b4417: telethon.tl.types.input_notify_users.InputNotifyUsers,
    0x4a95e84e: telethon.tl.types.input_notify_chats.InputNotifyChats,
    0xa429b886: telethon.tl.types.input_notify_all.InputNotifyAll,
    0xf03064d8: telethon.tl.types.input_peer_notify_events_empty.InputPeerNotifyEventsEmpty,
    0xe86a2c74: telethon.tl.types.input_peer_notify_events_all.InputPeerNotifyEventsAll,
    0x38935eb2: telethon.tl.types.input_peer_notify_settings.InputPeerNotifySettings,
    0xadd53cb3: telethon.tl.types.peer_notify_events_empty.PeerNotifyEventsEmpty,
    0x6d1ded88: telethon.tl.types.peer_notify_events_all.PeerNotifyEventsAll,
    0x70a68512: telethon.tl.types.peer_notify_settings_empty.PeerNotifySettingsEmpty,
    0x9acda4c0: telethon.tl.types.peer_notify_settings.PeerNotifySettings,
    0x818426cd: telethon.tl.types.peer_settings.PeerSettings,
    0xccb03657: telethon.tl.types.wall_paper.WallPaper,
    0x63117f24: telethon.tl.types.wall_paper_solid.WallPaperSolid,
    0x58dbcab8: telethon.tl.types.input_report_reason_spam.InputReportReasonSpam,
    0x1e22c78d: telethon.tl.types.input_report_reason_violence.InputReportReasonViolence,
    0x2e59d922: telethon.tl.types.input_report_reason_pornography.InputReportReasonPornography,
    0xe1746d0a: telethon.tl.types.input_report_reason_other.InputReportReasonOther,
    0x5932fc03: telethon.tl.types.user_full.UserFull,
    0xf911c994: telethon.tl.types.contact.Contact,
    0xd0028438: telethon.tl.types.imported_contact.ImportedContact,
    0x561bc879: telethon.tl.types.contact_blocked.ContactBlocked,
    0xd3680c61: telethon.tl.types.contact_status.ContactStatus,
    0x3ace484c: telethon.tl.types.contacts.link.Link,
    0xb74ba9d2: telethon.tl.types.contacts.contacts_not_modified.ContactsNotModified,
    0x6f8b8cb2: telethon.tl.types.contacts.contacts.Contacts,
    0xad524315: telethon.tl.types.contacts.imported_contacts.ImportedContacts,
    0x1c138d15: telethon.tl.types.contacts.blocked.Blocked,
    0x900802a1: telethon.tl.types.contacts.blocked_slice.BlockedSlice,
    0x15ba6c40: telethon.tl.types.messages.dialogs.Dialogs,
    0x71e094f3: telethon.tl.types.messages.dialogs_slice.DialogsSlice,
    0x8c718e87: telethon.tl.types.messages.messages.Messages,
    0xb446ae3: telethon.tl.types.messages.messages_slice.MessagesSlice,
    0x99262e37: telethon.tl.types.messages.channel_messages.ChannelMessages,
    0x64ff9fd5: telethon.tl.types.messages.chats.Chats,
    0xe5d7d19c: telethon.tl.types.messages.chat_full.ChatFull,
    0xb45c69d1: telethon.tl.types.messages.affected_history.AffectedHistory,
    0x57e2f66c: telethon.tl.types.input_messages_filter_empty.InputMessagesFilterEmpty,
    0x9609a51c: telethon.tl.types.input_messages_filter_photos.InputMessagesFilterPhotos,
    0x9fc00e65: telethon.tl.types.input_messages_filter_video.InputMessagesFilterVideo,
    0x56e9f0e4: telethon.tl.types.input_messages_filter_photo_video.InputMessagesFilterPhotoVideo,
    0xd95e73bb: telethon.tl.types.input_messages_filter_photo_video_documents.InputMessagesFilterPhotoVideoDocuments,
    0x9eddf188: telethon.tl.types.input_messages_filter_document.InputMessagesFilterDocument,
    0x7ef0dd87: telethon.tl.types.input_messages_filter_url.InputMessagesFilterUrl,
    0xffc86587: telethon.tl.types.input_messages_filter_gif.InputMessagesFilterGif,
    0x50f5c392: telethon.tl.types.input_messages_filter_voice.InputMessagesFilterVoice,
    0x3751b49e: telethon.tl.types.input_messages_filter_music.InputMessagesFilterMusic,
    0x3a20ecb8: telethon.tl.types.input_messages_filter_chat_photos.InputMessagesFilterChatPhotos,
    0x1f2b0afd: telethon.tl.types.update_new_message.UpdateNewMessage,
    0x4e90bfd6: telethon.tl.types.update_message_id.UpdateMessageID,
    0xa20db0e5: telethon.tl.types.update_delete_messages.UpdateDeleteMessages,
    0x5c486927: telethon.tl.types.update_user_typing.UpdateUserTyping,
    0x9a65ea1f: telethon.tl.types.update_chat_user_typing.UpdateChatUserTyping,
    0x7761198: telethon.tl.types.update_chat_participants.UpdateChatParticipants,
    0x1bfbd823: telethon.tl.types.update_user_status.UpdateUserStatus,
    0xa7332b73: telethon.tl.types.update_user_name.UpdateUserName,
    0x95313b0c: telethon.tl.types.update_user_photo.UpdateUserPhoto,
    0x2575bbb9: telethon.tl.types.update_contact_registered.UpdateContactRegistered,
    0x9d2e67c5: telethon.tl.types.update_contact_link.UpdateContactLink,
    0x8f06529a: telethon.tl.types.update_new_authorization.UpdateNewAuthorization,
    0x12bcbd9a: telethon.tl.types.update_new_encrypted_message.UpdateNewEncryptedMessage,
    0x1710f156: telethon.tl.types.update_encrypted_chat_typing.UpdateEncryptedChatTyping,
    0xb4a2e88d: telethon.tl.types.update_encryption.UpdateEncryption,
    0x38fe25b7: telethon.tl.types.update_encrypted_messages_read.UpdateEncryptedMessagesRead,
    0xea4b0e5c: telethon.tl.types.update_chat_participant_add.UpdateChatParticipantAdd,
    0x6e5f8c22: telethon.tl.types.update_chat_participant_delete.UpdateChatParticipantDelete,
    0x8e5e9873: telethon.tl.types.update_dc_options.UpdateDcOptions,
    0x80ece81a: telethon.tl.types.update_user_blocked.UpdateUserBlocked,
    0xbec268ef: telethon.tl.types.update_notify_settings.UpdateNotifySettings,
    0x382dd3e4: telethon.tl.types.update_service_notification.UpdateServiceNotification,
    0xee3b272a: telethon.tl.types.update_privacy.UpdatePrivacy,
    0x12b9417b: telethon.tl.types.update_user_phone.UpdateUserPhone,
    0x9961fd5c: telethon.tl.types.update_read_history_inbox.UpdateReadHistoryInbox,
    0x2f2f21bf: telethon.tl.types.update_read_history_outbox.UpdateReadHistoryOutbox,
    0x7f891213: telethon.tl.types.update_web_page.UpdateWebPage,
    0x68c13933: telethon.tl.types.update_read_messages_contents.UpdateReadMessagesContents,
    0xeb0467fb: telethon.tl.types.update_channel_too_long.UpdateChannelTooLong,
    0xb6d45656: telethon.tl.types.update_channel.UpdateChannel,
    0x62ba04d9: telethon.tl.types.update_new_channel_message.UpdateNewChannelMessage,
    0x4214f37f: telethon.tl.types.update_read_channel_inbox.UpdateReadChannelInbox,
    0xc37521c9: telethon.tl.types.update_delete_channel_messages.UpdateDeleteChannelMessages,
    0x98a12b4b: telethon.tl.types.update_channel_message_views.UpdateChannelMessageViews,
    0x6e947941: telethon.tl.types.update_chat_admins.UpdateChatAdmins,
    0xb6901959: telethon.tl.types.update_chat_participant_admin.UpdateChatParticipantAdmin,
    0x688a30aa: telethon.tl.types.update_new_sticker_set.UpdateNewStickerSet,
    0xbb2d201: telethon.tl.types.update_sticker_sets_order.UpdateStickerSetsOrder,
    0x43ae3dec: telethon.tl.types.update_sticker_sets.UpdateStickerSets,
    0x9375341e: telethon.tl.types.update_saved_gifs.UpdateSavedGifs,
    0x54826690: telethon.tl.types.update_bot_inline_query.UpdateBotInlineQuery,
    0xe48f964: telethon.tl.types.update_bot_inline_send.UpdateBotInlineSend,
    0x1b3f4df7: telethon.tl.types.update_edit_channel_message.UpdateEditChannelMessage,
    0x98592475: telethon.tl.types.update_channel_pinned_message.UpdateChannelPinnedMessage,
    0xe73547e1: telethon.tl.types.update_bot_callback_query.UpdateBotCallbackQuery,
    0xe40370a3: telethon.tl.types.update_edit_message.UpdateEditMessage,
    0xf9d27a5a: telethon.tl.types.update_inline_bot_callback_query.UpdateInlineBotCallbackQuery,
    0x25d6c9c7: telethon.tl.types.update_read_channel_outbox.UpdateReadChannelOutbox,
    0xee2bb969: telethon.tl.types.update_draft_message.UpdateDraftMessage,
    0x571d2742: telethon.tl.types.update_read_featured_stickers.UpdateReadFeaturedStickers,
    0x9a422c20: telethon.tl.types.update_recent_stickers.UpdateRecentStickers,
    0xa229dd06: telethon.tl.types.update_config.UpdateConfig,
    0x3354678f: telethon.tl.types.update_pts_changed.UpdatePtsChanged,
    0xa56c2a3e: telethon.tl.types.updates.state.State,
    0x5d75a138: telethon.tl.types.updates.difference_empty.DifferenceEmpty,
    0xf49ca0: telethon.tl.types.updates.difference.Difference,
    0xa8fb1981: telethon.tl.types.updates.difference_slice.DifferenceSlice,
    0xe317af7e: telethon.tl.types.updates_too_long.UpdatesTooLong,
    0x914fbf11: telethon.tl.types.update_short_message.UpdateShortMessage,
    0x16812688: telethon.tl.types.update_short_chat_message.UpdateShortChatMessage,
    0x78d4dec1: telethon.tl.types.update_short.UpdateShort,
    0x725b04c3: telethon.tl.types.updates_combined.UpdatesCombined,
    0x74ae4240: telethon.tl.types.updates_tg.UpdatesTg,
    0x11f1331c: telethon.tl.types.update_short_sent_message.UpdateShortSentMessage,
    0x8dca6aa5: telethon.tl.types.photos.photos.Photos,
    0x15051f54: telethon.tl.types.photos.photos_slice.PhotosSlice,
    0x20212ca8: telethon.tl.types.photos.photo.Photo,
    0x96a18d5: telethon.tl.types.upload.file.File,
    0x5d8c6cc: telethon.tl.types.dc_option.DcOption,
    0x9a6b2e2a: telethon.tl.types.config.Config,
    0x8e1a1775: telethon.tl.types.nearest_dc.NearestDc,
    0x8987f311: telethon.tl.types.help.app_update.AppUpdate,
    0xc45a6536: telethon.tl.types.help.no_app_update.NoAppUpdate,
    0x18cb9f78: telethon.tl.types.help.invite_text.InviteText,
    0xab7ec0a0: telethon.tl.types.encrypted_chat_empty.EncryptedChatEmpty,
    0x3bf703dc: telethon.tl.types.encrypted_chat_waiting.EncryptedChatWaiting,
    0xc878527e: telethon.tl.types.encrypted_chat_requested.EncryptedChatRequested,
    0xfa56ce36: telethon.tl.types.encrypted_chat.EncryptedChat,
    0x13d6dd27: telethon.tl.types.encrypted_chat_discarded.EncryptedChatDiscarded,
    0xf141b5e1: telethon.tl.types.input_encrypted_chat.InputEncryptedChat,
    0xc21f497e: telethon.tl.types.encrypted_file_empty.EncryptedFileEmpty,
    0x4a70994c: telethon.tl.types.encrypted_file.EncryptedFile,
    0x1837c364: telethon.tl.types.input_encrypted_file_empty.InputEncryptedFileEmpty,
    0x64bd0306: telethon.tl.types.input_encrypted_file_uploaded.InputEncryptedFileUploaded,
    0x5a17b5e5: telethon.tl.types.input_encrypted_file.InputEncryptedFile,
    0x2dc173c8: telethon.tl.types.input_encrypted_file_big_uploaded.InputEncryptedFileBigUploaded,
    0xed18c118: telethon.tl.types.encrypted_message.EncryptedMessage,
    0x23734b06: telethon.tl.types.encrypted_message_service.EncryptedMessageService,
    0xc0e24635: telethon.tl.types.messages.dh_config_not_modified.DhConfigNotModified,
    0x2c221edd: telethon.tl.types.messages.dh_config.DhConfig,
    0x560f8935: telethon.tl.types.messages.sent_encrypted_message.SentEncryptedMessage,
    0x9493ff32: telethon.tl.types.messages.sent_encrypted_file.SentEncryptedFile,
    0x72f0eaae: telethon.tl.types.input_document_empty.InputDocumentEmpty,
    0x18798952: telethon.tl.types.input_document.InputDocument,
    0x36f8c871: telethon.tl.types.document_empty.DocumentEmpty,
    0x87232bc7: telethon.tl.types.document.Document,
    0x17c6b5f6: telethon.tl.types.help.support.Support,
    0x9fd40bd8: telethon.tl.types.notify_peer.NotifyPeer,
    0xb4c83b4c: telethon.tl.types.notify_users.NotifyUsers,
    0xc007cec3: telethon.tl.types.notify_chats.NotifyChats,
    0x74d07c60: telethon.tl.types.notify_all.NotifyAll,
    0x16bf744e: telethon.tl.types.send_message_typing_action.SendMessageTypingAction,
    0xfd5ec8f5: telethon.tl.types.send_message_cancel_action.SendMessageCancelAction,
    0xa187d66f: telethon.tl.types.send_message_record_video_action.SendMessageRecordVideoAction,
    0xe9763aec: telethon.tl.types.send_message_upload_video_action.SendMessageUploadVideoAction,
    0xd52f73f7: telethon.tl.types.send_message_record_audio_action.SendMessageRecordAudioAction,
    0xf351d7ab: telethon.tl.types.send_message_upload_audio_action.SendMessageUploadAudioAction,
    0xd1d34a26: telethon.tl.types.send_message_upload_photo_action.SendMessageUploadPhotoAction,
    0xaa0cd9e4: telethon.tl.types.send_message_upload_document_action.SendMessageUploadDocumentAction,
    0x176f8ba1: telethon.tl.types.send_message_geo_location_action.SendMessageGeoLocationAction,
    0x628cbc6f: telethon.tl.types.send_message_choose_contact_action.SendMessageChooseContactAction,
    0xdd6a8f48: telethon.tl.types.send_message_game_play_action.SendMessageGamePlayAction,
    0x15c2c99a: telethon.tl.types.send_message_game_stop_action.SendMessageGameStopAction,
    0x1aa1f784: telethon.tl.types.contacts.found.Found,
    0x4f96cb18: telethon.tl.types.input_privacy_key_status_timestamp.InputPrivacyKeyStatusTimestamp,
    0xbdfb0426: telethon.tl.types.input_privacy_key_chat_invite.InputPrivacyKeyChatInvite,
    0xbc2eab30: telethon.tl.types.privacy_key_status_timestamp.PrivacyKeyStatusTimestamp,
    0x500e6dfa: telethon.tl.types.privacy_key_chat_invite.PrivacyKeyChatInvite,
    0xd09e07b: telethon.tl.types.input_privacy_value_allow_contacts.InputPrivacyValueAllowContacts,
    0x184b35ce: telethon.tl.types.input_privacy_value_allow_all.InputPrivacyValueAllowAll,
    0x131cc67f: telethon.tl.types.input_privacy_value_allow_users.InputPrivacyValueAllowUsers,
    0xba52007: telethon.tl.types.input_privacy_value_disallow_contacts.InputPrivacyValueDisallowContacts,
    0xd66b66c9: telethon.tl.types.input_privacy_value_disallow_all.InputPrivacyValueDisallowAll,
    0x90110467: telethon.tl.types.input_privacy_value_disallow_users.InputPrivacyValueDisallowUsers,
    0xfffe1bac: telethon.tl.types.privacy_value_allow_contacts.PrivacyValueAllowContacts,
    0x65427b82: telethon.tl.types.privacy_value_allow_all.PrivacyValueAllowAll,
    0x4d5bbe0c: telethon.tl.types.privacy_value_allow_users.PrivacyValueAllowUsers,
    0xf888fa1a: telethon.tl.types.privacy_value_disallow_contacts.PrivacyValueDisallowContacts,
    0x8b73e763: telethon.tl.types.privacy_value_disallow_all.PrivacyValueDisallowAll,
    0xc7f49b7: telethon.tl.types.privacy_value_disallow_users.PrivacyValueDisallowUsers,
    0x554abb6f: telethon.tl.types.account.privacy_rules.PrivacyRules,
    0xb8d0afdf: telethon.tl.types.account_days_ttl.AccountDaysTTL,
    0x6c37c15c: telethon.tl.types.document_attribute_image_size.DocumentAttributeImageSize,
    0x11b58939: telethon.tl.types.document_attribute_animated.DocumentAttributeAnimated,
    0x6319d612: telethon.tl.types.document_attribute_sticker.DocumentAttributeSticker,
    0x5910cccb: telethon.tl.types.document_attribute_video.DocumentAttributeVideo,
    0x9852f9c6: telethon.tl.types.document_attribute_audio.DocumentAttributeAudio,
    0x15590068: telethon.tl.types.document_attribute_filename.DocumentAttributeFilename,
    0x9801d2f7: telethon.tl.types.document_attribute_has_stickers.DocumentAttributeHasStickers,
    0xf1749a22: telethon.tl.types.messages.stickers_not_modified.StickersNotModified,
    0x8a8ecd32: telethon.tl.types.messages.stickers.Stickers,
    0x12b299d4: telethon.tl.types.sticker_pack.StickerPack,
    0xe86602c3: telethon.tl.types.messages.all_stickers_not_modified.AllStickersNotModified,
    0xedfd405f: telethon.tl.types.messages.all_stickers.AllStickers,
    0xae636f24: telethon.tl.types.disabled_feature.DisabledFeature,
    0x84d19185: telethon.tl.types.messages.affected_messages.AffectedMessages,
    0x5f4f9247: telethon.tl.types.contact_link_unknown.ContactLinkUnknown,
    0xfeedd3ad: telethon.tl.types.contact_link_none.ContactLinkNone,
    0x268f3f59: telethon.tl.types.contact_link_has_phone.ContactLinkHasPhone,
    0xd502c2d0: telethon.tl.types.contact_link_contact.ContactLinkContact,
    0xeb1477e8: telethon.tl.types.web_page_empty.WebPageEmpty,
    0xc586da1c: telethon.tl.types.web_page_pending.WebPagePending,
    0xca820ed7: telethon.tl.types.web_page.WebPage,
    0x7bf2e6f6: telethon.tl.types.authorization.Authorization,
    0x1250abde: telethon.tl.types.account.authorizations.Authorizations,
    0x96dabc18: telethon.tl.types.account.no_password.NoPassword,
    0x7c18141c: telethon.tl.types.account.password.Password,
    0xb7b72ab3: telethon.tl.types.account.password_settings.PasswordSettings,
    0x86916deb: telethon.tl.types.account.password_input_settings.PasswordInputSettings,
    0x137948a5: telethon.tl.types.auth.password_recovery.PasswordRecovery,
    0xa384b779: telethon.tl.types.received_notify_message.ReceivedNotifyMessage,
    0x69df3769: telethon.tl.types.chat_invite_empty.ChatInviteEmpty,
    0xfc2e05bc: telethon.tl.types.chat_invite_exported.ChatInviteExported,
    0x5a686d7c: telethon.tl.types.chat_invite_already.ChatInviteAlready,
    0xdb74f558: telethon.tl.types.chat_invite.ChatInvite,
    0xffb62b95: telethon.tl.types.input_sticker_set_empty.InputStickerSetEmpty,
    0x9de7a269: telethon.tl.types.input_sticker_set_id.InputStickerSetID,
    0x861cc8a0: telethon.tl.types.input_sticker_set_short_name.InputStickerSetShortName,
    0xcd303b41: telethon.tl.types.sticker_set.StickerSet,
    0xb60a24a6: telethon.tl.types.messages.sticker_set.StickerSet,
    0xc27ac8c7: telethon.tl.types.bot_command.BotCommand,
    0x98e81d3a: telethon.tl.types.bot_info.BotInfo,
    0xa2fa4880: telethon.tl.types.keyboard_button.KeyboardButton,
    0x258aff05: telethon.tl.types.keyboard_button_url.KeyboardButtonUrl,
    0x683a5e46: telethon.tl.types.keyboard_button_callback.KeyboardButtonCallback,
    0xb16a6c29: telethon.tl.types.keyboard_button_request_phone.KeyboardButtonRequestPhone,
    0xfc796b3f: telethon.tl.types.keyboard_button_request_geo_location.KeyboardButtonRequestGeoLocation,
    0x568a748: telethon.tl.types.keyboard_button_switch_inline.KeyboardButtonSwitchInline,
    0x50f41ccf: telethon.tl.types.keyboard_button_game.KeyboardButtonGame,
    0x77608b83: telethon.tl.types.keyboard_button_row.KeyboardButtonRow,
    0xa03e5b85: telethon.tl.types.reply_keyboard_hide.ReplyKeyboardHide,
    0xf4108aa0: telethon.tl.types.reply_keyboard_force_reply.ReplyKeyboardForceReply,
    0x3502758c: telethon.tl.types.reply_keyboard_markup.ReplyKeyboardMarkup,
    0x48a30254: telethon.tl.types.reply_inline_markup.ReplyInlineMarkup,
    0xaf7e0394: telethon.tl.types.help.app_changelog_empty.AppChangelogEmpty,
    0x4668e6bd: telethon.tl.types.help.app_changelog.AppChangelog,
    0xbb92ba95: telethon.tl.types.message_entity_unknown.MessageEntityUnknown,
    0xfa04579d: telethon.tl.types.message_entity_mention.MessageEntityMention,
    0x6f635b0d: telethon.tl.types.message_entity_hashtag.MessageEntityHashtag,
    0x6cef8ac7: telethon.tl.types.message_entity_bot_command.MessageEntityBotCommand,
    0x6ed02538: telethon.tl.types.message_entity_url.MessageEntityUrl,
    0x64e475c2: telethon.tl.types.message_entity_email.MessageEntityEmail,
    0xbd610bc9: telethon.tl.types.message_entity_bold.MessageEntityBold,
    0x826f8b60: telethon.tl.types.message_entity_italic.MessageEntityItalic,
    0x28a20571: telethon.tl.types.message_entity_code.MessageEntityCode,
    0x73924be0: telethon.tl.types.message_entity_pre.MessageEntityPre,
    0x76a6d327: telethon.tl.types.message_entity_text_url.MessageEntityTextUrl,
    0x352dca58: telethon.tl.types.message_entity_mention_name.MessageEntityMentionName,
    0x208e68c9: telethon.tl.types.input_message_entity_mention_name.InputMessageEntityMentionName,
    0xee8c1e86: telethon.tl.types.input_channel_empty.InputChannelEmpty,
    0xafeb712e: telethon.tl.types.input_channel.InputChannel,
    0x7f077ad9: telethon.tl.types.contacts.resolved_peer.ResolvedPeer,
    0xae30253: telethon.tl.types.message_range.MessageRange,
    0x3e11affb: telethon.tl.types.updates.channel_difference_empty.ChannelDifferenceEmpty,
    0x410dee07: telethon.tl.types.updates.channel_difference_too_long.ChannelDifferenceTooLong,
    0x2064674e: telethon.tl.types.updates.channel_difference.ChannelDifference,
    0x94d42ee7: telethon.tl.types.channel_messages_filter_empty.ChannelMessagesFilterEmpty,
    0xcd77d957: telethon.tl.types.channel_messages_filter.ChannelMessagesFilter,
    0x15ebac1d: telethon.tl.types.channel_participant.ChannelParticipant,
    0xa3289a6d: telethon.tl.types.channel_participant_self.ChannelParticipantSelf,
    0x91057fef: telethon.tl.types.channel_participant_moderator.ChannelParticipantModerator,
    0x98192d61: telethon.tl.types.channel_participant_editor.ChannelParticipantEditor,
    0x8cc5e69a: telethon.tl.types.channel_participant_kicked.ChannelParticipantKicked,
    0xe3e2e1f9: telethon.tl.types.channel_participant_creator.ChannelParticipantCreator,
    0xde3f3c79: telethon.tl.types.channel_participants_recent.ChannelParticipantsRecent,
    0xb4608969: telethon.tl.types.channel_participants_admins.ChannelParticipantsAdmins,
    0x3c37bb7a: telethon.tl.types.channel_participants_kicked.ChannelParticipantsKicked,
    0xb0d1865b: telethon.tl.types.channel_participants_bots.ChannelParticipantsBots,
    0xb285a0c6: telethon.tl.types.channel_role_empty.ChannelRoleEmpty,
    0x9618d975: telethon.tl.types.channel_role_moderator.ChannelRoleModerator,
    0x820bfe8c: telethon.tl.types.channel_role_editor.ChannelRoleEditor,
    0xf56ee2a8: telethon.tl.types.channels.channel_participants.ChannelParticipants,
    0xd0d9b163: telethon.tl.types.channels.channel_participant.ChannelParticipant,
    0xf1ee3e90: telethon.tl.types.help.terms_of_service.TermsOfService,
    0x162ecc1f: telethon.tl.types.found_gif.FoundGif,
    0x9c750409: telethon.tl.types.found_gif_cached.FoundGifCached,
    0x450a1c0a: telethon.tl.types.messages.found_gifs.FoundGifs,
    0xe8025ca2: telethon.tl.types.messages.saved_gifs_not_modified.SavedGifsNotModified,
    0x2e0709a5: telethon.tl.types.messages.saved_gifs.SavedGifs,
    0x292fed13: telethon.tl.types.input_bot_inline_message_media_auto.InputBotInlineMessageMediaAuto,
    0x3dcd7a87: telethon.tl.types.input_bot_inline_message_text.InputBotInlineMessageText,
    0xf4a59de1: telethon.tl.types.input_bot_inline_message_media_geo.InputBotInlineMessageMediaGeo,
    0xaaafadc8: telethon.tl.types.input_bot_inline_message_media_venue.InputBotInlineMessageMediaVenue,
    0x2daf01a7: telethon.tl.types.input_bot_inline_message_media_contact.InputBotInlineMessageMediaContact,
    0x4b425864: telethon.tl.types.input_bot_inline_message_game.InputBotInlineMessageGame,
    0x2cbbe15a: telethon.tl.types.input_bot_inline_result.InputBotInlineResult,
    0xa8d864a7: telethon.tl.types.input_bot_inline_result_photo.InputBotInlineResultPhoto,
    0xfff8fdc4: telethon.tl.types.input_bot_inline_result_document.InputBotInlineResultDocument,
    0x4fa417f2: telethon.tl.types.input_bot_inline_result_game.InputBotInlineResultGame,
    0xa74b15b: telethon.tl.types.bot_inline_message_media_auto.BotInlineMessageMediaAuto,
    0x8c7f65e2: telethon.tl.types.bot_inline_message_text.BotInlineMessageText,
    0x3a8fd8b8: telethon.tl.types.bot_inline_message_media_geo.BotInlineMessageMediaGeo,
    0x4366232e: telethon.tl.types.bot_inline_message_media_venue.BotInlineMessageMediaVenue,
    0x35edb4d4: telethon.tl.types.bot_inline_message_media_contact.BotInlineMessageMediaContact,
    0x9bebaeb9: telethon.tl.types.bot_inline_result.BotInlineResult,
    0x17db940b: telethon.tl.types.bot_inline_media_result.BotInlineMediaResult,
    0x256709a6: telethon.tl.types.messages.bot_results.BotResults,
    0x1f486803: telethon.tl.types.exported_message_link.ExportedMessageLink,
    0xc786ddcb: telethon.tl.types.message_fwd_header.MessageFwdHeader,
    0x72a3158c: telethon.tl.types.auth.code_type_sms.CodeTypeSms,
    0x741cd3e3: telethon.tl.types.auth.code_type_call.CodeTypeCall,
    0x226ccefb: telethon.tl.types.auth.code_type_flash_call.CodeTypeFlashCall,
    0x3dbb5986: telethon.tl.types.auth.sent_code_type_app.SentCodeTypeApp,
    0xc000bba2: telethon.tl.types.auth.sent_code_type_sms.SentCodeTypeSms,
    0x5353e5a7: telethon.tl.types.auth.sent_code_type_call.SentCodeTypeCall,
    0xab03c6d9: telethon.tl.types.auth.sent_code_type_flash_call.SentCodeTypeFlashCall,
    0xb10df1fb: telethon.tl.types.messages.bot_callback_answer.BotCallbackAnswer,
    0x26b5dde6: telethon.tl.types.messages.message_edit_data.MessageEditData,
    0x890c3d89: telethon.tl.types.input_bot_inline_message_id.InputBotInlineMessageID,
    0x3c20629f: telethon.tl.types.inline_bot_switch_pm.InlineBotSwitchPM,
    0x3371c354: telethon.tl.types.messages.peer_dialogs.PeerDialogs,
    0xedcdc05b: telethon.tl.types.top_peer.TopPeer,
    0xab661b5b: telethon.tl.types.top_peer_category_bots_pm.TopPeerCategoryBotsPM,
    0x148677e2: telethon.tl.types.top_peer_category_bots_inline.TopPeerCategoryBotsInline,
    0x637b7ed: telethon.tl.types.top_peer_category_correspondents.TopPeerCategoryCorrespondents,
    0xbd17a14a: telethon.tl.types.top_peer_category_groups.TopPeerCategoryGroups,
    0x161d9628: telethon.tl.types.top_peer_category_channels.TopPeerCategoryChannels,
    0xfb834291: telethon.tl.types.top_peer_category_peers.TopPeerCategoryPeers,
    0xde266ef5: telethon.tl.types.contacts.top_peers_not_modified.TopPeersNotModified,
    0x70b772a8: telethon.tl.types.contacts.top_peers.TopPeers,
    0xba4baec5: telethon.tl.types.draft_message_empty.DraftMessageEmpty,
    0xfd8e711f: telethon.tl.types.draft_message.DraftMessage,
    0x4ede3cf: telethon.tl.types.messages.featured_stickers_not_modified.FeaturedStickersNotModified,
    0xf89d88e5: telethon.tl.types.messages.featured_stickers.FeaturedStickers,
    0xb17f890: telethon.tl.types.messages.recent_stickers_not_modified.RecentStickersNotModified,
    0x5ce20970: telethon.tl.types.messages.recent_stickers.RecentStickers,
    0x4fcba9c8: telethon.tl.types.messages.archived_stickers.ArchivedStickers,
    0x38641628: telethon.tl.types.messages.sticker_set_install_result_success.StickerSetInstallResultSuccess,
    0x35e410a8: telethon.tl.types.messages.sticker_set_install_result_archive.StickerSetInstallResultArchive,
    0x6410a5d2: telethon.tl.types.sticker_set_covered.StickerSetCovered,
    0x3407e51b: telethon.tl.types.sticker_set_multi_covered.StickerSetMultiCovered,
    0xaed6dbb2: telethon.tl.types.mask_coords.MaskCoords,
    0x4a992157: telethon.tl.types.input_stickered_media_photo.InputStickeredMediaPhoto,
    0x438865b: telethon.tl.types.input_stickered_media_document.InputStickeredMediaDocument,
    0xbdf9653b: telethon.tl.types.game.Game,
    0x32c3e77: telethon.tl.types.input_game_id.InputGameID,
    0xc331e80a: telethon.tl.types.input_game_short_name.InputGameShortName,
    0x58fffcd0: telethon.tl.types.high_score.HighScore,
    0x9a3bfd99: telethon.tl.types.messages.high_scores.HighScores,
    0xcb9f372d: telethon.tl.functions.invoke_after_msg.InvokeAfterMsgRequest,
    0x3dc4b4f0: telethon.tl.functions.invoke_after_msgs.InvokeAfterMsgsRequest,
    0x69796de9: telethon.tl.functions.init_connection.InitConnectionRequest,
    0xda9b0d0d: telethon.tl.functions.invoke_with_layer.InvokeWithLayerRequest,
    0xbf9459b7: telethon.tl.functions.invoke_without_updates.InvokeWithoutUpdatesRequest,
    0x6fe51dfb: telethon.tl.functions.auth.check_phone.CheckPhoneRequest,
    0x86aef0ec: telethon.tl.functions.auth.send_code.SendCodeRequest,
    0x1b067634: telethon.tl.functions.auth.sign_up.SignUpRequest,
    0xbcd51581: telethon.tl.functions.auth.sign_in.SignInRequest,
    0x5717da40: telethon.tl.functions.auth.log_out.LogOutRequest,
    0x9fab0d1a: telethon.tl.functions.auth.reset_authorizations.ResetAuthorizationsRequest,
    0x771c1d97: telethon.tl.functions.auth.send_invites.SendInvitesRequest,
    0xe5bfffcd: telethon.tl.functions.auth.export_authorization.ExportAuthorizationRequest,
    0xe3ef9613: telethon.tl.functions.auth.import_authorization.ImportAuthorizationRequest,
    0xcdd42a05: telethon.tl.functions.auth.bind_temp_auth_key.BindTempAuthKeyRequest,
    0x67a3ff2c: telethon.tl.functions.auth.import_bot_authorization.ImportBotAuthorizationRequest,
    0xa63011e: telethon.tl.functions.auth.check_password.CheckPasswordRequest,
    0xd897bc66: telethon.tl.functions.auth.request_password_recovery.RequestPasswordRecoveryRequest,
    0x4ea56e92: telethon.tl.functions.auth.recover_password.RecoverPasswordRequest,
    0x3ef1a9bf: telethon.tl.functions.auth.resend_code.ResendCodeRequest,
    0x1f040578: telethon.tl.functions.auth.cancel_code.CancelCodeRequest,
    0x8e48a188: telethon.tl.functions.auth.drop_temp_auth_keys.DropTempAuthKeysRequest,
    0x637ea878: telethon.tl.functions.account.register_device.RegisterDeviceRequest,
    0x65c55b40: telethon.tl.functions.account.unregister_device.UnregisterDeviceRequest,
    0x84be5b93: telethon.tl.functions.account.update_notify_settings.UpdateNotifySettingsRequest,
    0x12b3ad31: telethon.tl.functions.account.get_notify_settings.GetNotifySettingsRequest,
    0xdb7e1747: telethon.tl.functions.account.reset_notify_settings.ResetNotifySettingsRequest,
    0x78515775: telethon.tl.functions.account.update_profile.UpdateProfileRequest,
    0x6628562c: telethon.tl.functions.account.update_status.UpdateStatusRequest,
    0xc04cfac2: telethon.tl.functions.account.get_wall_papers.GetWallPapersRequest,
    0xae189d5f: telethon.tl.functions.account.report_peer.ReportPeerRequest,
    0x2714d86c: telethon.tl.functions.account.check_username.CheckUsernameRequest,
    0x3e0bdd7c: telethon.tl.functions.account.update_username.UpdateUsernameRequest,
    0xdadbc950: telethon.tl.functions.account.get_privacy.GetPrivacyRequest,
    0xc9f81ce8: telethon.tl.functions.account.set_privacy.SetPrivacyRequest,
    0x418d4e0b: telethon.tl.functions.account.delete_account.DeleteAccountRequest,
    0x8fc711d: telethon.tl.functions.account.get_account_ttl.GetAccountTTLRequest,
    0x2442485e: telethon.tl.functions.account.set_account_ttl.SetAccountTTLRequest,
    0x8e57deb: telethon.tl.functions.account.send_change_phone_code.SendChangePhoneCodeRequest,
    0x70c32edb: telethon.tl.functions.account.change_phone.ChangePhoneRequest,
    0x38df3532: telethon.tl.functions.account.update_device_locked.UpdateDeviceLockedRequest,
    0xe320c158: telethon.tl.functions.account.get_authorizations.GetAuthorizationsRequest,
    0xdf77f3bc: telethon.tl.functions.account.reset_authorization.ResetAuthorizationRequest,
    0x548a30f5: telethon.tl.functions.account.get_password.GetPasswordRequest,
    0xbc8d11bb: telethon.tl.functions.account.get_password_settings.GetPasswordSettingsRequest,
    0xfa7c4b86: telethon.tl.functions.account.update_password_settings.UpdatePasswordSettingsRequest,
    0x1516d7bd: telethon.tl.functions.account.send_confirm_phone_code.SendConfirmPhoneCodeRequest,
    0x5f2178c3: telethon.tl.functions.account.confirm_phone.ConfirmPhoneRequest,
    0xd91a548: telethon.tl.functions.users.get_users.GetUsersRequest,
    0xca30a5b1: telethon.tl.functions.users.get_full_user.GetFullUserRequest,
    0xc4a353ee: telethon.tl.functions.contacts.get_statuses.GetStatusesRequest,
    0x22c6aa08: telethon.tl.functions.contacts.get_contacts.GetContactsRequest,
    0xda30b32d: telethon.tl.functions.contacts.import_contacts.ImportContactsRequest,
    0x8e953744: telethon.tl.functions.contacts.delete_contact.DeleteContactRequest,
    0x59ab389e: telethon.tl.functions.contacts.delete_contacts.DeleteContactsRequest,
    0x332b49fc: telethon.tl.functions.contacts.block.BlockRequest,
    0xe54100bd: telethon.tl.functions.contacts.unblock.UnblockRequest,
    0xf57c350f: telethon.tl.functions.contacts.get_blocked.GetBlockedRequest,
    0x84e53737: telethon.tl.functions.contacts.export_card.ExportCardRequest,
    0x4fe196fe: telethon.tl.functions.contacts.import_card.ImportCardRequest,
    0x11f812d8: telethon.tl.functions.contacts.search.SearchRequest,
    0xf93ccba3: telethon.tl.functions.contacts.resolve_username.ResolveUsernameRequest,
    0xd4982db5: telethon.tl.functions.contacts.get_top_peers.GetTopPeersRequest,
    0x1ae373ac: telethon.tl.functions.contacts.reset_top_peer_rating.ResetTopPeerRatingRequest,
    0x4222fa74: telethon.tl.functions.messages.get_messages.GetMessagesRequest,
    0x6b47f94d: telethon.tl.functions.messages.get_dialogs.GetDialogsRequest,
    0xafa92846: telethon.tl.functions.messages.get_history.GetHistoryRequest,
    0xd4569248: telethon.tl.functions.messages.search.SearchRequest,
    0xe306d3a: telethon.tl.functions.messages.read_history.ReadHistoryRequest,
    0x1c015b09: telethon.tl.functions.messages.delete_history.DeleteHistoryRequest,
    0xa5f18925: telethon.tl.functions.messages.delete_messages.DeleteMessagesRequest,
    0x5a954c0: telethon.tl.functions.messages.received_messages.ReceivedMessagesRequest,
    0xa3825e50: telethon.tl.functions.messages.set_typing.SetTypingRequest,
    0xfa88427a: telethon.tl.functions.messages.send_message.SendMessageRequest,
    0xc8f16791: telethon.tl.functions.messages.send_media.SendMediaRequest,
    0x708e0195: telethon.tl.functions.messages.forward_messages.ForwardMessagesRequest,
    0xcf1592db: telethon.tl.functions.messages.report_spam.ReportSpamRequest,
    0xa8f1709b: telethon.tl.functions.messages.hide_report_spam.HideReportSpamRequest,
    0x3672e09c: telethon.tl.functions.messages.get_peer_settings.GetPeerSettingsRequest,
    0x3c6aa187: telethon.tl.functions.messages.get_chats.GetChatsRequest,
    0x3b831c66: telethon.tl.functions.messages.get_full_chat.GetFullChatRequest,
    0xdc452855: telethon.tl.functions.messages.edit_chat_title.EditChatTitleRequest,
    0xca4c79d8: telethon.tl.functions.messages.edit_chat_photo.EditChatPhotoRequest,
    0xf9a0aa09: telethon.tl.functions.messages.add_chat_user.AddChatUserRequest,
    0xe0611f16: telethon.tl.functions.messages.delete_chat_user.DeleteChatUserRequest,
    0x9cb126e: telethon.tl.functions.messages.create_chat.CreateChatRequest,
    0x33963bf9: telethon.tl.functions.messages.forward_message.ForwardMessageRequest,
    0x26cf8950: telethon.tl.functions.messages.get_dh_config.GetDhConfigRequest,
    0xf64daf43: telethon.tl.functions.messages.request_encryption.RequestEncryptionRequest,
    0x3dbc0415: telethon.tl.functions.messages.accept_encryption.AcceptEncryptionRequest,
    0xedd923c5: telethon.tl.functions.messages.discard_encryption.DiscardEncryptionRequest,
    0x791451ed: telethon.tl.functions.messages.set_encrypted_typing.SetEncryptedTypingRequest,
    0x7f4b690a: telethon.tl.functions.messages.read_encrypted_history.ReadEncryptedHistoryRequest,
    0xa9776773: telethon.tl.functions.messages.send_encrypted.SendEncryptedRequest,
    0x9a901b66: telethon.tl.functions.messages.send_encrypted_file.SendEncryptedFileRequest,
    0x32d439a4: telethon.tl.functions.messages.send_encrypted_service.SendEncryptedServiceRequest,
    0x55a5bb66: telethon.tl.functions.messages.received_queue.ReceivedQueueRequest,
    0x36a73f77: telethon.tl.functions.messages.read_message_contents.ReadMessageContentsRequest,
    0x1c9618b1: telethon.tl.functions.messages.get_all_stickers.GetAllStickersRequest,
    0x25223e24: telethon.tl.functions.messages.get_web_page_preview.GetWebPagePreviewRequest,
    0x7d885289: telethon.tl.functions.messages.export_chat_invite.ExportChatInviteRequest,
    0x3eadb1bb: telethon.tl.functions.messages.check_chat_invite.CheckChatInviteRequest,
    0x6c50051c: telethon.tl.functions.messages.import_chat_invite.ImportChatInviteRequest,
    0x2619a90e: telethon.tl.functions.messages.get_sticker_set.GetStickerSetRequest,
    0xc78fe460: telethon.tl.functions.messages.install_sticker_set.InstallStickerSetRequest,
    0xf96e55de: telethon.tl.functions.messages.uninstall_sticker_set.UninstallStickerSetRequest,
    0xe6df7378: telethon.tl.functions.messages.start_bot.StartBotRequest,
    0xc4c8a55d: telethon.tl.functions.messages.get_messages_views.GetMessagesViewsRequest,
    0xec8bd9e1: telethon.tl.functions.messages.toggle_chat_admins.ToggleChatAdminsRequest,
    0xa9e69f2e: telethon.tl.functions.messages.edit_chat_admin.EditChatAdminRequest,
    0x15a3b8e3: telethon.tl.functions.messages.migrate_chat.MigrateChatRequest,
    0x9e3cacb0: telethon.tl.functions.messages.search_global.SearchGlobalRequest,
    0x78337739: telethon.tl.functions.messages.reorder_sticker_sets.ReorderStickerSetsRequest,
    0x338e2464: telethon.tl.functions.messages.get_document_by_hash.GetDocumentByHashRequest,
    0xbf9a776b: telethon.tl.functions.messages.search_gifs.SearchGifsRequest,
    0x83bf3d52: telethon.tl.functions.messages.get_saved_gifs.GetSavedGifsRequest,
    0x327a30cb: telethon.tl.functions.messages.save_gif.SaveGifRequest,
    0x514e999d: telethon.tl.functions.messages.get_inline_bot_results.GetInlineBotResultsRequest,
    0xeb5ea206: telethon.tl.functions.messages.set_inline_bot_results.SetInlineBotResultsRequest,
    0xb16e06fe: telethon.tl.functions.messages.send_inline_bot_result.SendInlineBotResultRequest,
    0xfda68d36: telethon.tl.functions.messages.get_message_edit_data.GetMessageEditDataRequest,
    0xce91e4ca: telethon.tl.functions.messages.edit_message.EditMessageRequest,
    0x130c2c85: telethon.tl.functions.messages.edit_inline_bot_message.EditInlineBotMessageRequest,
    0x810a9fec: telethon.tl.functions.messages.get_bot_callback_answer.GetBotCallbackAnswerRequest,
    0xc927d44b: telethon.tl.functions.messages.set_bot_callback_answer.SetBotCallbackAnswerRequest,
    0x2d9776b9: telethon.tl.functions.messages.get_peer_dialogs.GetPeerDialogsRequest,
    0xbc39e14b: telethon.tl.functions.messages.save_draft.SaveDraftRequest,
    0x6a3f8d65: telethon.tl.functions.messages.get_all_drafts.GetAllDraftsRequest,
    0x2dacca4f: telethon.tl.functions.messages.get_featured_stickers.GetFeaturedStickersRequest,
    0x5b118126: telethon.tl.functions.messages.read_featured_stickers.ReadFeaturedStickersRequest,
    0x5ea192c9: telethon.tl.functions.messages.get_recent_stickers.GetRecentStickersRequest,
    0x392718f8: telethon.tl.functions.messages.save_recent_sticker.SaveRecentStickerRequest,
    0x8999602d: telethon.tl.functions.messages.clear_recent_stickers.ClearRecentStickersRequest,
    0x57f17692: telethon.tl.functions.messages.get_archived_stickers.GetArchivedStickersRequest,
    0x65b8c79f: telethon.tl.functions.messages.get_mask_stickers.GetMaskStickersRequest,
    0xcc5b67cc: telethon.tl.functions.messages.get_attached_stickers.GetAttachedStickersRequest,
    0x8ef8ecc0: telethon.tl.functions.messages.set_game_score.SetGameScoreRequest,
    0x15ad9f64: telethon.tl.functions.messages.set_inline_game_score.SetInlineGameScoreRequest,
    0xe822649d: telethon.tl.functions.messages.get_game_high_scores.GetGameHighScoresRequest,
    0xf635e1b: telethon.tl.functions.messages.get_inline_game_high_scores.GetInlineGameHighScoresRequest,
    0xedd4882a: telethon.tl.functions.updates.get_state.GetStateRequest,
    0xa041495: telethon.tl.functions.updates.get_difference.GetDifferenceRequest,
    0xbb32d7c0: telethon.tl.functions.updates.get_channel_difference.GetChannelDifferenceRequest,
    0xf0bb5152: telethon.tl.functions.photos.update_profile_photo.UpdateProfilePhotoRequest,
    0x4f32c098: telethon.tl.functions.photos.upload_profile_photo.UploadProfilePhotoRequest,
    0x87cf7f2f: telethon.tl.functions.photos.delete_photos.DeletePhotosRequest,
    0x91cd32a8: telethon.tl.functions.photos.get_user_photos.GetUserPhotosRequest,
    0xb304a621: telethon.tl.functions.upload.save_file_part.SaveFilePartRequest,
    0xe3a6cfb5: telethon.tl.functions.upload.get_file.GetFileRequest,
    0xde7b673d: telethon.tl.functions.upload.save_big_file_part.SaveBigFilePartRequest,
    0xc4f9186b: telethon.tl.functions.help.get_config.GetConfigRequest,
    0x1fb33026: telethon.tl.functions.help.get_nearest_dc.GetNearestDcRequest,
    0xae2de196: telethon.tl.functions.help.get_app_update.GetAppUpdateRequest,
    0x6f02f748: telethon.tl.functions.help.save_app_log.SaveAppLogRequest,
    0x4d392343: telethon.tl.functions.help.get_invite_text.GetInviteTextRequest,
    0x9cdf08cd: telethon.tl.functions.help.get_support.GetSupportRequest,
    0xb921197a: telethon.tl.functions.help.get_app_changelog.GetAppChangelogRequest,
    0x350170f3: telethon.tl.functions.help.get_terms_of_service.GetTermsOfServiceRequest,
    0xcc104937: telethon.tl.functions.channels.read_history.ReadHistoryRequest,
    0x84c1fd4e: telethon.tl.functions.channels.delete_messages.DeleteMessagesRequest,
    0xd10dd71b: telethon.tl.functions.channels.delete_user_history.DeleteUserHistoryRequest,
    0xfe087810: telethon.tl.functions.channels.report_spam.ReportSpamRequest,
    0x93d7b347: telethon.tl.functions.channels.get_messages.GetMessagesRequest,
    0x24d98f92: telethon.tl.functions.channels.get_participants.GetParticipantsRequest,
    0x546dd7a6: telethon.tl.functions.channels.get_participant.GetParticipantRequest,
    0xa7f6bbb: telethon.tl.functions.channels.get_channels.GetChannelsRequest,
    0x8736a09: telethon.tl.functions.channels.get_full_channel.GetFullChannelRequest,
    0xf4893d7f: telethon.tl.functions.channels.create_channel.CreateChannelRequest,
    0x13e27f1e: telethon.tl.functions.channels.edit_about.EditAboutRequest,
    0xeb7611d0: telethon.tl.functions.channels.edit_admin.EditAdminRequest,
    0x566decd0: telethon.tl.functions.channels.edit_title.EditTitleRequest,
    0xf12e57c9: telethon.tl.functions.channels.edit_photo.EditPhotoRequest,
    0x10e6bd2c: telethon.tl.functions.channels.check_username.CheckUsernameRequest,
    0x3514b3de: telethon.tl.functions.channels.update_username.UpdateUsernameRequest,
    0x24b524c5: telethon.tl.functions.channels.join_channel.JoinChannelRequest,
    0xf836aa95: telethon.tl.functions.channels.leave_channel.LeaveChannelRequest,
    0x199f3a6c: telethon.tl.functions.channels.invite_to_channel.InviteToChannelRequest,
    0xa672de14: telethon.tl.functions.channels.kick_from_channel.KickFromChannelRequest,
    0xc7560885: telethon.tl.functions.channels.export_invite.ExportInviteRequest,
    0xc0111fe3: telethon.tl.functions.channels.delete_channel.DeleteChannelRequest,
    0x49609307: telethon.tl.functions.channels.toggle_invites.ToggleInvitesRequest,
    0xc846d22d: telethon.tl.functions.channels.export_message_link.ExportMessageLinkRequest,
    0x1f69b606: telethon.tl.functions.channels.toggle_signatures.ToggleSignaturesRequest,
    0xa72ded52: telethon.tl.functions.channels.update_pinned_message.UpdatePinnedMessageRequest,
    0x8d8d82d7: telethon.tl.functions.channels.get_admined_public_channels.GetAdminedPublicChannelsRequest,
}



from telethon.tl.mtproto_request import MTProtoRequest


class SetBotCallbackAnswerRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.setBotCallbackAnswer#c927d44b flags:None alert:flags.1?true query_id:long message:flags.0?string url:flags.2?string = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xc927d44b

    def __init__(self, query_id, alert=None, message=None, url=None):
        """
        :param alert: Telegram type: «true».
        :param query_id: Telegram type: «long».
        :param message: Telegram type: «string».
        :param url: Telegram type: «string».
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.alert = alert
        self.query_id = query_id
        self.message = message
        self.url = url

    def on_send(self, writer):
        writer.write_int(SetBotCallbackAnswerRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 1) if self.alert else 0
        flags |= (1 << 0) if self.message else 0
        flags |= (1 << 2) if self.url else 0
        writer.write_int(flags)

        writer.write_long(self.query_id)
        if self.message:
            writer.tgwrite_string(self.message)

        if self.url:
            writer.tgwrite_string(self.url)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SetBotCallbackAnswerRequest(None, None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.setBotCallbackAnswer#c927d44b flags:None alert:flags.1?true query_id:long message:flags.0?string url:flags.2?string = Bool'

    def __str__(self):
        return '(messages.setBotCallbackAnswer (ID: 0xc927d44b) = (alert={}, query_id={}, message={}, url={}))'.format(str(self.alert), str(self.query_id), str(self.message), str(self.url))



from telethon.tl.mtproto_request import MTProtoRequest


class SearchRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    contacts.search#11f812d8 q:string limit:int = contacts.Found"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x11f812d8

    def __init__(self, q, limit):
        """
        :param q: Telegram type: «string».
        :param limit: Telegram type: «int».
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.q = q
        self.limit = limit

    def on_send(self, writer):
        writer.write_int(SearchRequest.constructor_id, signed=False)
        writer.tgwrite_string(self.q)
        writer.write_int(self.limit)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SearchRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'contacts.search#11f812d8 q:string limit:int = contacts.Found'

    def __str__(self):
        return '(contacts.search (ID: 0x11f812d8) = (q={}, limit={}))'.format(str(self.q), str(self.limit))



from telethon.tl.mtproto_request import MTProtoRequest


class InputBotInlineResultDocument(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputBotInlineResultDocument#fff8fdc4 flags:None id:string type:string title:flags.1?string description:flags.2?string document:InputDocument send_message:InputBotInlineMessage = InputBotInlineResult"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xfff8fdc4

    def __init__(self, id, type, document, send_message, title=None, description=None):
        """
        :param id: Telegram type: «string».
        :param type: Telegram type: «string».
        :param title: Telegram type: «string».
        :param description: Telegram type: «string».
        :param document: Telegram type: «InputDocument».
        :param send_message: Telegram type: «InputBotInlineMessage».
        """
        super().__init__()

        self.id = id
        self.type = type
        self.title = title
        self.description = description
        self.document = document
        self.send_message = send_message

    def on_send(self, writer):
        writer.write_int(InputBotInlineResultDocument.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 1) if self.title else 0
        flags |= (1 << 2) if self.description else 0
        writer.write_int(flags)

        writer.tgwrite_string(self.id)
        writer.tgwrite_string(self.type)
        if self.title:
            writer.tgwrite_string(self.title)

        if self.description:
            writer.tgwrite_string(self.description)

        self.document.on_send(writer)
        self.send_message.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputBotInlineResultDocument(None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        self.id = reader.tgread_string()
        self.type = reader.tgread_string()
        if (flags & (1 << 1)) != 0:
            self.title = reader.tgread_string()

        if (flags & (1 << 2)) != 0:
            self.description = reader.tgread_string()

        self.document = reader.tgread_object()
        self.send_message = reader.tgread_object()

    def __repr__(self):
        return 'inputBotInlineResultDocument#fff8fdc4 flags:None id:string type:string title:flags.1?string description:flags.2?string document:InputDocument send_message:InputBotInlineMessage = InputBotInlineResult'

    def __str__(self):
        return '(inputBotInlineResultDocument (ID: 0xfff8fdc4) = (id={}, type={}, title={}, description={}, document={}, send_message={}))'.format(str(self.id), str(self.type), str(self.title), str(self.description), str(self.document), str(self.send_message))



from telethon.tl.mtproto_request import MTProtoRequest


class MessageEditData(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.messageEditData#26b5dde6 flags:None caption:flags.0?true = messages.MessageEditData"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x26b5dde6

    def __init__(self, caption=None):
        """
        :param caption: Telegram type: «true».
        """
        super().__init__()

        self.caption = caption

    def on_send(self, writer):
        writer.write_int(MessageEditData.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.caption else 0
        writer.write_int(flags)


    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return MessageEditData(None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.caption = True  # Arbitrary not-None value, no need to read since it is a flag

    def __repr__(self):
        return 'messages.messageEditData#26b5dde6 flags:None caption:flags.0?true = messages.MessageEditData'

    def __str__(self):
        return '(messages.messageEditData (ID: 0x26b5dde6) = (caption={}))'.format(str(self.caption))



from telethon.tl.mtproto_request import MTProtoRequest


class InputMediaContact(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputMediaContact#a6e45987 phone_number:string first_name:string last_name:string = InputMedia"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xa6e45987

    def __init__(self, phone_number, first_name, last_name):
        """
        :param phone_number: Telegram type: «string».
        :param first_name: Telegram type: «string».
        :param last_name: Telegram type: «string».
        """
        super().__init__()

        self.phone_number = phone_number
        self.first_name = first_name
        self.last_name = last_name

    def on_send(self, writer):
        writer.write_int(InputMediaContact.constructor_id, signed=False)
        writer.tgwrite_string(self.phone_number)
        writer.tgwrite_string(self.first_name)
        writer.tgwrite_string(self.last_name)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputMediaContact(None, None, None)

    def on_response(self, reader):
        self.phone_number = reader.tgread_string()
        self.first_name = reader.tgread_string()
        self.last_name = reader.tgread_string()

    def __repr__(self):
        return 'inputMediaContact#a6e45987 phone_number:string first_name:string last_name:string = InputMedia'

    def __str__(self):
        return '(inputMediaContact (ID: 0xa6e45987) = (phone_number={}, first_name={}, last_name={}))'.format(str(self.phone_number), str(self.first_name), str(self.last_name))



from telethon.tl.mtproto_request import MTProtoRequest


class ToggleChatAdminsRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.toggleChatAdmins#ec8bd9e1 chat_id:int enabled:Bool = Updates"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xec8bd9e1

    def __init__(self, chat_id, enabled):
        """
        :param chat_id: Telegram type: «int».
        :param enabled: Telegram type: «Bool».
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.chat_id = chat_id
        self.enabled = enabled

    def on_send(self, writer):
        writer.write_int(ToggleChatAdminsRequest.constructor_id, signed=False)
        writer.write_int(self.chat_id)
        writer.tgwrite_bool(self.enabled)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ToggleChatAdminsRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.toggleChatAdmins#ec8bd9e1 chat_id:int enabled:Bool = Updates'

    def __str__(self):
        return '(messages.toggleChatAdmins (ID: 0xec8bd9e1) = (chat_id={}, enabled={}))'.format(str(self.chat_id), str(self.enabled))



from telethon.tl.mtproto_request import MTProtoRequest


class UpdateEncryption(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateEncryption#b4a2e88d chat:EncryptedChat date:date = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xb4a2e88d

    def __init__(self, chat, date):
        """
        :param chat: Telegram type: «EncryptedChat».
        :param date: Telegram type: «date».
        """
        super().__init__()

        self.chat = chat
        self.date = date

    def on_send(self, writer):
        writer.write_int(UpdateEncryption.constructor_id, signed=False)
        self.chat.on_send(writer)
        writer.tgwrite_date(self.date)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateEncryption(None, None)

    def on_response(self, reader):
        self.chat = reader.tgread_object()
        self.date = reader.tgread_date()

    def __repr__(self):
        return 'updateEncryption#b4a2e88d chat:EncryptedChat date:date = Update'

    def __str__(self):
        return '(updateEncryption (ID: 0xb4a2e88d) = (chat={}, date={}))'.format(str(self.chat), str(self.date))



from telethon.tl.mtproto_request import MTProtoRequest


class EditChatPhotoRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.editChatPhoto#ca4c79d8 chat_id:int photo:InputChatPhoto = Updates"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xca4c79d8

    def __init__(self, chat_id, photo):
        """
        :param chat_id: Telegram type: «int».
        :param photo: Telegram type: «InputChatPhoto».
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.chat_id = chat_id
        self.photo = photo

    def on_send(self, writer):
        writer.write_int(EditChatPhotoRequest.constructor_id, signed=False)
        writer.write_int(self.chat_id)
        self.photo.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return EditChatPhotoRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.editChatPhoto#ca4c79d8 chat_id:int photo:InputChatPhoto = Updates'

    def __str__(self):
        return '(messages.editChatPhoto (ID: 0xca4c79d8) = (chat_id={}, photo={}))'.format(str(self.chat_id), str(self.photo))



from telethon.tl.mtproto_request import MTProtoRequest


class NotifyPeer(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    notifyPeer#9fd40bd8 peer:Peer = NotifyPeer"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x9fd40bd8

    def __init__(self, peer):
        """
        :param peer: Telegram type: «Peer».
        """
        super().__init__()

        self.peer = peer

    def on_send(self, writer):
        writer.write_int(NotifyPeer.constructor_id, signed=False)
        self.peer.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return NotifyPeer(None)

    def on_response(self, reader):
        self.peer = reader.tgread_object()

    def __repr__(self):
        return 'notifyPeer#9fd40bd8 peer:Peer = NotifyPeer'

    def __str__(self):
        return '(notifyPeer (ID: 0x9fd40bd8) = (peer={}))'.format(str(self.peer))



from telethon.tl.mtproto_request import MTProtoRequest


class InputStickeredMediaDocument(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputStickeredMediaDocument#0438865b id:InputDocument = InputStickeredMedia"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x438865b

    def __init__(self, id):
        """
        :param id: Telegram type: «InputDocument».
        """
        super().__init__()

        self.id = id

    def on_send(self, writer):
        writer.write_int(InputStickeredMediaDocument.constructor_id, signed=False)
        self.id.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputStickeredMediaDocument(None)

    def on_response(self, reader):
        self.id = reader.tgread_object()

    def __repr__(self):
        return 'inputStickeredMediaDocument#0438865b id:InputDocument = InputStickeredMedia'

    def __str__(self):
        return '(inputStickeredMediaDocument (ID: 0x438865b) = (id={}))'.format(str(self.id))



from telethon.tl.mtproto_request import MTProtoRequest


class UpdateBotInlineSend(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateBotInlineSend#0e48f964 flags:None user_id:int query:string geo:flags.0?GeoPoint id:string msg_id:flags.1?InputBotInlineMessageID = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xe48f964

    def __init__(self, user_id, query, id, geo=None, msg_id=None):
        """
        :param user_id: Telegram type: «int».
        :param query: Telegram type: «string».
        :param geo: Telegram type: «GeoPoint».
        :param id: Telegram type: «string».
        :param msg_id: Telegram type: «InputBotInlineMessageID».
        """
        super().__init__()

        self.user_id = user_id
        self.query = query
        self.geo = geo
        self.id = id
        self.msg_id = msg_id

    def on_send(self, writer):
        writer.write_int(UpdateBotInlineSend.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.geo else 0
        flags |= (1 << 1) if self.msg_id else 0
        writer.write_int(flags)

        writer.write_int(self.user_id)
        writer.tgwrite_string(self.query)
        if self.geo:
            self.geo.on_send(writer)

        writer.tgwrite_string(self.id)
        if self.msg_id:
            self.msg_id.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateBotInlineSend(None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        self.user_id = reader.read_int()
        self.query = reader.tgread_string()
        if (flags & (1 << 0)) != 0:
            self.geo = reader.tgread_object()

        self.id = reader.tgread_string()
        if (flags & (1 << 1)) != 0:
            self.msg_id = reader.tgread_object()

    def __repr__(self):
        return 'updateBotInlineSend#0e48f964 flags:None user_id:int query:string geo:flags.0?GeoPoint id:string msg_id:flags.1?InputBotInlineMessageID = Update'

    def __str__(self):
        return '(updateBotInlineSend (ID: 0xe48f964) = (user_id={}, query={}, geo={}, id={}, msg_id={}))'.format(str(self.user_id), str(self.query), str(self.geo), str(self.id), str(self.msg_id))



from telethon.tl.mtproto_request import MTProtoRequest


class GetAttachedStickersRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.getAttachedStickers#cc5b67cc media:InputStickeredMedia = Vector<StickerSetCovered>"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xcc5b67cc

    def __init__(self, media):
        """
        :param media: Telegram type: «InputStickeredMedia».
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.media = media

    def on_send(self, writer):
        writer.write_int(GetAttachedStickersRequest.constructor_id, signed=False)
        self.media.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetAttachedStickersRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.getAttachedStickers#cc5b67cc media:InputStickeredMedia = Vector<StickerSetCovered>'

    def __str__(self):
        return '(messages.getAttachedStickers (ID: 0xcc5b67cc) = (media={}))'.format(str(self.media))



from telethon.tl.mtproto_request import MTProtoRequest


class SendConfirmPhoneCodeRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    account.sendConfirmPhoneCode#1516d7bd flags:None allow_flashcall:flags.0?true hash:string current_number:flags.0?Bool = auth.SentCode"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x1516d7bd

    def __init__(self, hash, allow_flashcall=None, current_number=None):
        """
        :param allow_flashcall: Telegram type: «true».
        :param hash: Telegram type: «string».
        :param current_number: Telegram type: «Bool».
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.allow_flashcall = allow_flashcall
        self.hash = hash
        self.current_number = current_number

    def on_send(self, writer):
        writer.write_int(SendConfirmPhoneCodeRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.allow_flashcall else 0
        flags |= (1 << 0) if self.current_number else 0
        writer.write_int(flags)

        writer.tgwrite_string(self.hash)
        if self.current_number:
            writer.tgwrite_bool(self.current_number)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SendConfirmPhoneCodeRequest(None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'account.sendConfirmPhoneCode#1516d7bd flags:None allow_flashcall:flags.0?true hash:string current_number:flags.0?Bool = auth.SentCode'

    def __str__(self):
        return '(account.sendConfirmPhoneCode (ID: 0x1516d7bd) = (allow_flashcall={}, hash={}, current_number={}))'.format(str(self.allow_flashcall), str(self.hash), str(self.current_number))



from telethon.tl.mtproto_request import MTProtoRequest


class InputFile(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputFile#f52ff27f id:long parts:int name:string md5_checksum:string = InputFile"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xf52ff27f

    def __init__(self, id, parts, name, md5_checksum):
        """
        :param id: Telegram type: «long».
        :param parts: Telegram type: «int».
        :param name: Telegram type: «string».
        :param md5_checksum: Telegram type: «string».
        """
        super().__init__()

        self.id = id
        self.parts = parts
        self.name = name
        self.md5_checksum = md5_checksum

    def on_send(self, writer):
        writer.write_int(InputFile.constructor_id, signed=False)
        writer.write_long(self.id)
        writer.write_int(self.parts)
        writer.tgwrite_string(self.name)
        writer.tgwrite_string(self.md5_checksum)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputFile(None, None, None, None)

    def on_response(self, reader):
        self.id = reader.read_long()
        self.parts = reader.read_int()
        self.name = reader.tgread_string()
        self.md5_checksum = reader.tgread_string()

    def __repr__(self):
        return 'inputFile#f52ff27f id:long parts:int name:string md5_checksum:string = InputFile'

    def __str__(self):
        return '(inputFile (ID: 0xf52ff27f) = (id={}, parts={}, name={}, md5_checksum={}))'.format(str(self.id), str(self.parts), str(self.name), str(self.md5_checksum))



from telethon.tl.mtproto_request import MTProtoRequest


class SendInvitesRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    auth.sendInvites#771c1d97 phone_numbers:Vector<string> message:string = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x771c1d97

    def __init__(self, phone_numbers, message):
        """
        :param phone_numbers: Telegram type: «string». Must be a list.
        :param message: Telegram type: «string».
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.phone_numbers = phone_numbers
        self.message = message

    def on_send(self, writer):
        writer.write_int(SendInvitesRequest.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.phone_numbers))
        for phone_numbers_item in self.phone_numbers:
            writer.tgwrite_string(phone_numbers_item)

        writer.tgwrite_string(self.message)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SendInvitesRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'auth.sendInvites#771c1d97 phone_numbers:Vector<string> message:string = Bool'

    def __str__(self):
        return '(auth.sendInvites (ID: 0x771c1d97) = (phone_numbers={}, message={}))'.format(None if not self.phone_numbers else [str(_) for _ in self.phone_numbers], str(self.message))



from telethon.tl.mtproto_request import MTProtoRequest


class ReqPqRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    req_pq#60469778 nonce:int128 = ResPQ"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x60469778

    def __init__(self, nonce):
        """
        :param nonce: Telegram type: «int128».
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.nonce = nonce

    def on_send(self, writer):
        writer.write_int(ReqPqRequest.constructor_id, signed=False)
        writer.write_large_int(self.nonce, bits=128)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ReqPqRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'req_pq#60469778 nonce:int128 = ResPQ'

    def __str__(self):
        return '(req_pq (ID: 0x60469778) = (nonce={}))'.format(str(self.nonce))



from telethon.tl.mtproto_request import MTProtoRequest


class MessageActionChannelMigrateFrom(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messageActionChannelMigrateFrom#b055eaee title:string chat_id:int = MessageAction"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xb055eaee

    def __init__(self, title, chat_id):
        """
        :param title: Telegram type: «string».
        :param chat_id: Telegram type: «int».
        """
        super().__init__()

        self.title = title
        self.chat_id = chat_id

    def on_send(self, writer):
        writer.write_int(MessageActionChannelMigrateFrom.constructor_id, signed=False)
        writer.tgwrite_string(self.title)
        writer.write_int(self.chat_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return MessageActionChannelMigrateFrom(None, None)

    def on_response(self, reader):
        self.title = reader.tgread_string()
        self.chat_id = reader.read_int()

    def __repr__(self):
        return 'messageActionChannelMigrateFrom#b055eaee title:string chat_id:int = MessageAction'

    def __str__(self):
        return '(messageActionChannelMigrateFrom (ID: 0xb055eaee) = (title={}, chat_id={}))'.format(str(self.title), str(self.chat_id))



from telethon.tl.mtproto_request import MTProtoRequest


class UpdateEncryptedMessagesRead(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateEncryptedMessagesRead#38fe25b7 chat_id:int max_date:date date:date = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x38fe25b7

    def __init__(self, chat_id, max_date, date):
        """
        :param chat_id: Telegram type: «int».
        :param max_date: Telegram type: «date».
        :param date: Telegram type: «date».
        """
        super().__init__()

        self.chat_id = chat_id
        self.max_date = max_date
        self.date = date

    def on_send(self, writer):
        writer.write_int(UpdateEncryptedMessagesRead.constructor_id, signed=False)
        writer.write_int(self.chat_id)
        writer.tgwrite_date(self.max_date)
        writer.tgwrite_date(self.date)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateEncryptedMessagesRead(None, None, None)

    def on_response(self, reader):
        self.chat_id = reader.read_int()
        self.max_date = reader.tgread_date()
        self.date = reader.tgread_date()

    def __repr__(self):
        return 'updateEncryptedMessagesRead#38fe25b7 chat_id:int max_date:date date:date = Update'

    def __str__(self):
        return '(updateEncryptedMessagesRead (ID: 0x38fe25b7) = (chat_id={}, max_date={}, date={}))'.format(str(self.chat_id), str(self.max_date), str(self.date))



from telethon.tl.mtproto_request import MTProtoRequest


class UpdateNewAuthorization(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateNewAuthorization#8f06529a auth_key_id:long date:date device:string location:string = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x8f06529a

    def __init__(self, auth_key_id, date, device, location):
        """
        :param auth_key_id: Telegram type: «long».
        :param date: Telegram type: «date».
        :param device: Telegram type: «string».
        :param location: Telegram type: «string».
        """
        super().__init__()

        self.auth_key_id = auth_key_id
        self.date = date
        self.device = device
        self.location = location

    def on_send(self, writer):
        writer.write_int(UpdateNewAuthorization.constructor_id, signed=False)
        writer.write_long(self.auth_key_id)
        writer.tgwrite_date(self.date)
        writer.tgwrite_string(self.device)
        writer.tgwrite_string(self.location)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateNewAuthorization(None, None, None, None)

    def on_response(self, reader):
        self.auth_key_id = reader.read_long()
        self.date = reader.tgread_date()
        self.device = reader.tgread_string()
        self.location = reader.tgread_string()

    def __repr__(self):
        return 'updateNewAuthorization#8f06529a auth_key_id:long date:date device:string location:string = Update'

    def __str__(self):
        return '(updateNewAuthorization (ID: 0x8f06529a) = (auth_key_id={}, date={}, device={}, location={}))'.format(str(self.auth_key_id), str(self.date), str(self.device), str(self.location))



from telethon.tl.mtproto_request import MTProtoRequest


class UpdateUserName(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateUserName#a7332b73 user_id:int first_name:string last_name:string username:string = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xa7332b73

    def __init__(self, user_id, first_name, last_name, username):
        """
        :param user_id: Telegram type: «int».
        :param first_name: Telegram type: «string».
        :param last_name: Telegram type: «string».
        :param username: Telegram type: «string».
        """
        super().__init__()

        self.user_id = user_id
        self.first_name = first_name
        self.last_name = last_name
        self.username = username

    def on_send(self, writer):
        writer.write_int(UpdateUserName.constructor_id, signed=False)
        writer.write_int(self.user_id)
        writer.tgwrite_string(self.first_name)
        writer.tgwrite_string(self.last_name)
        writer.tgwrite_string(self.username)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateUserName(None, None, None, None)

    def on_response(self, reader):
        self.user_id = reader.read_int()
        self.first_name = reader.tgread_string()
        self.last_name = reader.tgread_string()
        self.username = reader.tgread_string()

    def __repr__(self):
        return 'updateUserName#a7332b73 user_id:int first_name:string last_name:string username:string = Update'

    def __str__(self):
        return '(updateUserName (ID: 0xa7332b73) = (user_id={}, first_name={}, last_name={}, username={}))'.format(str(self.user_id), str(self.first_name), str(self.last_name), str(self.username))



from telethon.tl.mtproto_request import MTProtoRequest


class ReadEncryptedHistoryRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.readEncryptedHistory#7f4b690a peer:InputEncryptedChat max_date:date = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x7f4b690a

    def __init__(self, peer, max_date):
        """
        :param peer: Telegram type: «InputEncryptedChat».
        :param max_date: Telegram type: «date».
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.peer = peer
        self.max_date = max_date

    def on_send(self, writer):
        writer.write_int(ReadEncryptedHistoryRequest.constructor_id, signed=False)
        self.peer.on_send(writer)
        writer.tgwrite_date(self.max_date)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ReadEncryptedHistoryRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.readEncryptedHistory#7f4b690a peer:InputEncryptedChat max_date:date = Bool'

    def __str__(self):
        return '(messages.readEncryptedHistory (ID: 0x7f4b690a) = (peer={}, max_date={}))'.format(str(self.peer), str(self.max_date))



from telethon.tl.functions.photos.update_profile_photo import UpdateProfilePhotoRequest
from telethon.tl.functions.photos.upload_profile_photo import UploadProfilePhotoRequest
from telethon.tl.functions.photos.delete_photos import DeletePhotosRequest
from telethon.tl.functions.photos.get_user_photos import GetUserPhotosRequest



from telethon.tl.mtproto_request import MTProtoRequest


class PingRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    ping#7abe77ec ping_id:long = Pong"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x7abe77ec

    def __init__(self, ping_id):
        """
        :param ping_id: Telegram type: «long».
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.ping_id = ping_id

    def on_send(self, writer):
        writer.write_int(PingRequest.constructor_id, signed=False)
        writer.write_long(self.ping_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PingRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'ping#7abe77ec ping_id:long = Pong'

    def __str__(self):
        return '(ping (ID: 0x7abe77ec) = (ping_id={}))'.format(str(self.ping_id))



from telethon.tl.mtproto_request import MTProtoRequest


class UpdateReadMessagesContents(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateReadMessagesContents#68c13933 messages:Vector<int> pts:int pts_count:int = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x68c13933

    def __init__(self, messages, pts, pts_count):
        """
        :param messages: Telegram type: «int». Must be a list.
        :param pts: Telegram type: «int».
        :param pts_count: Telegram type: «int».
        """
        super().__init__()

        self.messages = messages
        self.pts = pts
        self.pts_count = pts_count

    def on_send(self, writer):
        writer.write_int(UpdateReadMessagesContents.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.messages))
        for messages_item in self.messages:
            writer.write_int(messages_item)

        writer.write_int(self.pts)
        writer.write_int(self.pts_count)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateReadMessagesContents(None, None, None)

    def on_response(self, reader):
        reader.read_int()  # Vector's constructor ID
        self.messages = []  # Initialize an empty list
        messages_len = reader.read_int()
        for _ in range(messages_len):
            messages_item = reader.read_int()
            self.messages.append(messages_item)

        self.pts = reader.read_int()
        self.pts_count = reader.read_int()

    def __repr__(self):
        return 'updateReadMessagesContents#68c13933 messages:Vector<int> pts:int pts_count:int = Update'

    def __str__(self):
        return '(updateReadMessagesContents (ID: 0x68c13933) = (messages={}, pts={}, pts_count={}))'.format(None if not self.messages else [str(_) for _ in self.messages], str(self.pts), str(self.pts_count))



from telethon.tl.mtproto_request import MTProtoRequest


class PasswordInputSettings(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    account.passwordInputSettings#86916deb flags:None new_salt:flags.0?bytes new_password_hash:flags.0?bytes hint:flags.0?string email:flags.1?string = account.PasswordInputSettings"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x86916deb

    def __init__(self, new_salt=None, new_password_hash=None, hint=None, email=None):
        """
        :param new_salt: Telegram type: «bytes».
        :param new_password_hash: Telegram type: «bytes».
        :param hint: Telegram type: «string».
        :param email: Telegram type: «string».
        """
        super().__init__()

        self.new_salt = new_salt
        self.new_password_hash = new_password_hash
        self.hint = hint
        self.email = email

    def on_send(self, writer):
        writer.write_int(PasswordInputSettings.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.new_salt else 0
        flags |= (1 << 0) if self.new_password_hash else 0
        flags |= (1 << 0) if self.hint else 0
        flags |= (1 << 1) if self.email else 0
        writer.write_int(flags)

        if self.new_salt:
            writer.tgwrite_bytes(self.new_salt)

        if self.new_password_hash:
            writer.tgwrite_bytes(self.new_password_hash)

        if self.hint:
            writer.tgwrite_string(self.hint)

        if self.email:
            writer.tgwrite_string(self.email)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PasswordInputSettings(None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.new_salt = reader.tgread_bytes()

        if (flags & (1 << 0)) != 0:
            self.new_password_hash = reader.tgread_bytes()

        if (flags & (1 << 0)) != 0:
            self.hint = reader.tgread_string()

        if (flags & (1 << 1)) != 0:
            self.email = reader.tgread_string()

    def __repr__(self):
        return 'account.passwordInputSettings#86916deb flags:None new_salt:flags.0?bytes new_password_hash:flags.0?bytes hint:flags.0?string email:flags.1?string = account.PasswordInputSettings'

    def __str__(self):
        return '(account.passwordInputSettings (ID: 0x86916deb) = (new_salt={}, new_password_hash={}, hint={}, email={}))'.format(str(self.new_salt), str(self.new_password_hash), str(self.hint), str(self.email))



from telethon.tl.mtproto_request import MTProtoRequest


class SaveFilePartRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    upload.saveFilePart#b304a621 file_id:long file_part:int bytes:bytes = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xb304a621

    def __init__(self, file_id, file_part, bytes):
        """
        :param file_id: Telegram type: «long».
        :param file_part: Telegram type: «int».
        :param bytes: Telegram type: «bytes».
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.file_id = file_id
        self.file_part = file_part
        self.bytes = bytes

    def on_send(self, writer):
        writer.write_int(SaveFilePartRequest.constructor_id, signed=False)
        writer.write_long(self.file_id)
        writer.write_int(self.file_part)
        writer.tgwrite_bytes(self.bytes)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SaveFilePartRequest(None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'upload.saveFilePart#b304a621 file_id:long file_part:int bytes:bytes = Bool'

    def __str__(self):
        return '(upload.saveFilePart (ID: 0xb304a621) = (file_id={}, file_part={}, bytes={}))'.format(str(self.file_id), str(self.file_part), str(self.bytes))



from telethon.tl.mtproto_request import MTProtoRequest


class HideReportSpamRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.hideReportSpam#a8f1709b peer:InputPeer = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xa8f1709b

    def __init__(self, peer):
        """
        :param peer: Telegram type: «InputPeer».
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.peer = peer

    def on_send(self, writer):
        writer.write_int(HideReportSpamRequest.constructor_id, signed=False)
        self.peer.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return HideReportSpamRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.hideReportSpam#a8f1709b peer:InputPeer = Bool'

    def __str__(self):
        return '(messages.hideReportSpam (ID: 0xa8f1709b) = (peer={}))'.format(str(self.peer))



from telethon.tl.mtproto_request import MTProtoRequest


class Found(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    contacts.found#1aa1f784 results:Vector<Peer> chats:Vector<Chat> users:Vector<User> = contacts.Found"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x1aa1f784

    def __init__(self, results, chats, users):
        """
        :param results: Telegram type: «Peer». Must be a list.
        :param chats: Telegram type: «Chat». Must be a list.
        :param users: Telegram type: «User». Must be a list.
        """
        super().__init__()

        self.results = results
        self.chats = chats
        self.users = users

    def on_send(self, writer):
        writer.write_int(Found.constructor_id, signed=False)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.results))
        for results_item in self.results:
            results_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.chats))
        for chats_item in self.chats:
            chats_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.users))
        for users_item in self.users:
            users_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return Found(None, None, None)

    def on_response(self, reader):
        reader.read_int()  # Vector's constructor ID
        self.results = []  # Initialize an empty list
        results_len = reader.read_int()
        for _ in range(results_len):
            results_item = reader.tgread_object()
            self.results.append(results_item)

        reader.read_int()  # Vector's constructor ID
        self.chats = []  # Initialize an empty list
        chats_len = reader.read_int()
        for _ in range(chats_len):
            chats_item = reader.tgread_object()
            self.chats.append(chats_item)

        reader.read_int()  # Vector's constructor ID
        self.users = []  # Initialize an empty list
        users_len = reader.read_int()
        for _ in range(users_len):
            users_item = reader.tgread_object()
            self.users.append(users_item)

    def __repr__(self):
        return 'contacts.found#1aa1f784 results:Vector<Peer> chats:Vector<Chat> users:Vector<User> = contacts.Found'

    def __str__(self):
        return '(contacts.found (ID: 0x1aa1f784) = (results={}, chats={}, users={}))'.format(None if not self.results else [str(_) for _ in self.results], None if not self.chats else [str(_) for _ in self.chats], None if not self.users else [str(_) for _ in self.users])



from telethon.tl.mtproto_request import MTProtoRequest


class UpdateStickerSetsOrder(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateStickerSetsOrder#0bb2d201 flags:None masks:flags.0?true order:Vector<long> = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xbb2d201

    def __init__(self, order, masks=None):
        """
        :param masks: Telegram type: «true».
        :param order: Telegram type: «long». Must be a list.
        """
        super().__init__()

        self.masks = masks
        self.order = order

    def on_send(self, writer):
        writer.write_int(UpdateStickerSetsOrder.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.masks else 0
        writer.write_int(flags)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.order))
        for order_item in self.order:
            writer.write_long(order_item)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateStickerSetsOrder(None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.masks = True  # Arbitrary not-None value, no need to read since it is a flag

        reader.read_int()  # Vector's constructor ID
        self.order = []  # Initialize an empty list
        order_len = reader.read_int()
        for _ in range(order_len):
            order_item = reader.read_long()
            self.order.append(order_item)

    def __repr__(self):
        return 'updateStickerSetsOrder#0bb2d201 flags:None masks:flags.0?true order:Vector<long> = Update'

    def __str__(self):
        return '(updateStickerSetsOrder (ID: 0xbb2d201) = (masks={}, order={}))'.format(str(self.masks), None if not self.order else [str(_) for _ in self.order])
